@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: oswlog.h,v 1.9 2004/12/09 05:22:09 mcr Exp $
+ * RCSID $Id: oswlog.h,v 1.11 2005/01/26 00:52:16 mcr Exp $
  */
 
 #ifndef _OSWLOG_H_
@@ -26,6 +26,8 @@
 
 #if !defined(NO_DEBUG)
 
+#include "constants.h"
+
 extern lset_t base_debugging;	/* bits selecting what to report */
 extern lset_t cur_debugging;	/* current debugging level */
 
@@ -118,6 +120,7 @@ enum rc_type {
     RC_CRYPTOFAILED,    /* system too busy to perform required
 			 * cryptographic operations */
     RC_AGGRALGO,        /* multiple algorithms requested in phase 1 aggressive */
+    RC_FATAL,           /* fatal error encountered, and negotiation aborted */
 
     /* entry of secrets */
     RC_ENTERSECRET = 40,
