@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: constants.c,v 1.8 2004/10/19 03:17:54 mcr Exp $
+ * RCSID $Id: constants.c,v 1.11 2005/06/23 01:45:55 mcr Exp $
  */
 
 /*
@@ -86,6 +86,8 @@ const char *const debug_bit_names[] = {
 	"impair-delay-adns-txt-answer",
 	"impair-bust-mi2",
 	"impair-bust-mr2",
+	"impair-sa-creation",
+	"impair-die-oninfo",
 
 	NULL
     };
@@ -121,6 +123,11 @@ const char *const payload_name[] = {
 	"ISAKMP_NEXT_D",
 	"ISAKMP_NEXT_VID",
 	"ISAKMP_NEXT_MODECFG",  /* 14 */
+	"ISAKMP_NEXT_15",
+	"ISAKMP_NEXT_16",
+	"ISAKMP_NEXT_17",
+	"ISAKMP_NEXT_18",
+	"ISAKMP_NEXT_19",
 	"ISAKMP_NEXT_NAT-D",
 	"ISAKMP_NEXT_NAT-OA",
 	NULL
@@ -573,7 +580,7 @@ static const char *const oakley_enc_name_draft_aes_cbc_02[] = {
 	"OAKLEY_TWOFISH_CBC"	/*	65005	*/,
 };
 static const char *const oakley_enc_name_ssh[] = {
-	"OAKLEY_SSH_PRIVATE_65289",
+	"OAKLEY_TWOFISH_CBC_SSH",
 };
 enum_names oakley_enc_names_ssh =
     { 65289, 65289, oakley_enc_name_ssh, NULL };
@@ -909,7 +916,7 @@ enum_names ppk_names = { PPK_PSK, PPK_PIN, ppk_name, NULL };
 const char *const natt_type_bitnames[] = {
   "draft-ietf-ipsec-nat-t-ike-00/01",    /* 0 */
   "draft-ietf-ipsec-nat-t-ike-02/03",
-  "RFC XXXX (NAT-Traversal)",
+  "RFC 3947 (NAT-Traversal)",
   "3",                                   /* 3 */
   "4",   "5",   "6",   "7", 
   "8",   "9",   "10",  "11",
