@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: packet.c,v 1.47 2004/10/16 22:46:59 mcr Exp $
+ * RCSID $Id: packet.c,v 1.49 2005/01/23 18:53:56 mcr Exp $
  */
 
 #include <stdio.h>
@@ -630,9 +630,14 @@ struct_desc *const payload_descs[ISAKMP_NEXT_ROOF] = {
     &isakmp_notification_desc,		/* 11 ISAKMP_NEXT_N (Notification) */
     &isakmp_delete_desc,		/* 12 ISAKMP_NEXT_D (Delete) */
     &isakmp_vendor_id_desc,		/* 13 ISAKMP_NEXT_VID (Vendor ID) */
-    &isakmp_attr_desc,                  /* 14 ISAKMP_NEXT_ATTR (ModeCfg)  */    
-    &isakmp_nat_d,              	/* 15=130 ISAKMP_NEXT_NATD (NAT-D) */
-    &isakmp_nat_oa,             	/* 16=131 ISAKMP_NEXT_NATOA (NAT-OA) */
+    &isakmp_attr_desc,                  /* 14 ISAKMP_NEXT_ATTR (ModeCfg)  */
+    NULL,                               /* 15 */
+    NULL,                               /* 16 */
+    NULL,                               /* 17 */
+    NULL,                               /* 18 */
+    NULL,                               /* 19 */
+    &isakmp_nat_d,                      /* 20=130 ISAKMP_NEXT_NATD (NAT-D) */
+    &isakmp_nat_oa,                     /* 21=131 ISAKMP_NEXT_NATOA (NAT-OA) */
 };
 
 void
@@ -802,7 +807,10 @@ in_struct(void *struct_ptr, struct_desc *sd
 
     if (ins->roof - cur < (ptrdiff_t)sd->size)
     {
-	ugh = builddiag("not enough room in input packet for %s", sd->name);
+        ugh = builddiag("not enough room in input packet for %s"
+                        " (remain=%d, sd->size=%d)"
+                        , sd->name, ins->roof - cur, sd->size);
+
     }
     else
     {
