@@ -13,7 +13,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ipsec_ipcomp.h,v 1.3 2004/04/06 02:49:08 mcr Exp $
+ * RCSID $Id: ipsec_ipcomp.h,v 1.4 2004/07/10 19:08:41 mcr Exp $
  */
 
 #ifndef IPSEC_IPCOMP_H
@@ -30,9 +30,9 @@
 #define IPPROTO_COMP 108
 #endif /* IPPROTO_COMP */
 
-#ifdef CONFIG_IPSEC_DEBUG
+#ifdef CONFIG_KLIPS_DEBUG
 extern int sysctl_ipsec_debug_ipcomp;
-#endif /* CONFIG_IPSEC_DEBUG */
+#endif /* CONFIG_KLIPS_DEBUG */
 
 struct ipcomphdr {			/* IPCOMP header */
     __u8    ipcomp_nh;		/* Next header (protocol) */
@@ -63,6 +63,9 @@ extern struct xform_functions ipcomp_xform_funcs[];
 
 /*
  * $Log: ipsec_ipcomp.h,v $
+ * Revision 1.4  2004/07/10 19:08:41  mcr
+ * 	CONFIG_IPSEC -> CONFIG_KLIPS.
+ *
  * Revision 1.3  2004/04/06 02:49:08  mcr
  * 	pullup of algo code from alg-branch.
  *
