@@ -20,7 +20,10 @@
  */
 #define __NO_VERSION__
 
+#if defined (MODULE)
 #include <linux/module.h>
+#endif
+
 #include <linux/kernel.h> /* printk() */
 
 #include <linux/netdevice.h>   /* struct device, and other headers */
@@ -66,9 +69,6 @@
 #include "openswan/ipsec_alg.h"
 #include "openswan/ipsec_proto.h"
 
-#ifndef CONFIG_KLIPS_ALG
-#error This file _MUST_ be compiled with CONFIG_KLIPS_ALG enabled !
-#endif
 #if SADB_EALG_MAX < 255
 #warning Compiling with limited ESP support ( SADB_EALG_MAX < 256 )
 #endif
@@ -85,15 +85,20 @@ static struct list_head ipsec_alg_hash_table[IPSEC_ALG_HASHSZ];
 /* 
  * 	Must be already protected by lock 
  */
-static void __ipsec_alg_usage_inc(struct ipsec_alg *ixt) {
+static void __ipsec_alg_usage_inc(struct ipsec_alg *ixt)
+{
+#ifdef MODULE
 	if (ixt->ixt_module)
 		try_module_get(ixt->ixt_module);
+#endif
 	atomic_inc(&ixt->ixt_refcnt);
 }
 static void __ipsec_alg_usage_dec(struct ipsec_alg *ixt) {
 	atomic_dec(&ixt->ixt_refcnt);
+#ifdef MODULE
 	if (ixt->ixt_module)
 		module_put(ixt->ixt_module);
+#endif
 }
 
 #else
@@ -102,15 +107,19 @@ static void __ipsec_alg_usage_dec(struct ipsec_alg *ixt) {
  * 	Must be already protected by lock 
  */
 static void __ipsec_alg_usage_inc(struct ipsec_alg *ixt) {
+#ifdef MODULE
 	if (ixt->ixt_module) {
 		__MOD_INC_USE_COUNT(ixt->ixt_module);
 	}
+#endif
 	atomic_inc(&ixt->ixt_refcnt);
 }
 static void __ipsec_alg_usage_dec(struct ipsec_alg *ixt) {
 	atomic_dec(&ixt->ixt_refcnt);
+#ifdef MODULE
 	if (ixt->ixt_module)
 		__MOD_DEC_USE_COUNT(ixt->ixt_module);
+#endif
 }
 #endif
 
@@ -260,9 +269,9 @@ int ipsec_alg_esp_encrypt(struct ipsec_sa *sa_p, __u8 * idat,
 		    "entering with encalg=%d, ixt_e=%p\n",
 		    sa_p->ips_encalg, ixt_e);
 	if (ixt_e == NULL) {
-	  KLIPS_PRINT(debug_flag,
-			    "klips_debug:ipsec_alg_esp_encrypt: "
-			    "NULL ipsec_alg_enc object\n");
+	  KLIPS_ERROR(debug_flag,
+		      "klips_debug:ipsec_alg_esp_encrypt: "
+		      "NULL ipsec_alg_enc object\n");
 		return -1;
 	}
 	KLIPS_PRINT(debug_flag,
@@ -1020,6 +1029,7 @@ ipsec_xform_get_info(char *buffer,
  *	symbol problems for old modutils.
  */
 
+#ifdef CONFIG_MODULES
 #ifndef NET_26
 #if 0
 #ifndef EXPORT_SYMBOL_GPL 
@@ -1031,3 +1041,4 @@ EXPORT_SYMBOL(register_ipsec_alg);
 EXPORT_SYMBOL(unregister_ipsec_alg);
 EXPORT_SYMBOL(ipsec_alg_test);
 #endif
+#endif
