@@ -34,7 +34,7 @@
  *	special case: ipsec core modular with this static algo inside:
  *	must avoid MODULE magic for this file
  */
-#if CONFIG_KLIPS_MODULE && CONFIG_KLIPS_ENC_CRYPTOAPI
+#if defined(CONFIG_KLIPS_MODULE) && defined(CONFIG_KLIPS_ENC_CRYPTOAPI)
 #undef MODULE
 #endif
 
@@ -56,8 +56,10 @@
 #warning "No linux CryptoAPI found, install 2.4.22+ or 2.6.x"
 #define NO_CRYPTOAPI_SUPPORT
 #endif
-/*	Low Openswan header coupling	*/
+
+#include "openswan.h"
 #include "openswan/ipsec_alg.h"
+#include "openswan/ipsec_policy.h"
 
 #include <linux/crypto.h>
 #ifdef CRYPTO_API_VERSION_CODE
@@ -79,36 +81,44 @@ IPSEC_ALG_MODULE_INIT_STATIC( ipsec_cryptoapi_init )
 #include <linux/mm.h>
 
 #define CIPHERNAME_AES		"aes"
+#define CIPHERNAME_1DES		"des"
 #define CIPHERNAME_3DES		"des3_ede"
 #define CIPHERNAME_BLOWFISH	"blowfish"
 #define CIPHERNAME_CAST		"cast5"
 #define CIPHERNAME_SERPENT	"serpent"
 #define CIPHERNAME_TWOFISH	"twofish"
 
-#define ESP_3DES		3
-#define ESP_AES			12
-#define ESP_BLOWFISH		7	/* truely _constant_  :)  */
-#define ESP_CAST		6	/* quite constant :) */
 #define ESP_SERPENT		252	/* from ipsec drafts */
 #define ESP_TWOFISH		253	/* from ipsec drafts */
 
-#define AH_MD5			2
-#define AH_SHA			3
 #define DIGESTNAME_MD5		"md5"
 #define DIGESTNAME_SHA1		"sha1"
 
 MODULE_AUTHOR("Juanjo Ciarlante, Harpo MAxx, Luciano Ruete");
-static int debug=0;
-MODULE_PARM(debug, "i");
-static int test=0;
-MODULE_PARM(test, "i");
-static int excl=0;
-MODULE_PARM(excl, "i");
+static int debug_crypto=0;
+static int test_crypto=0;
+static int excl_crypto=0;
 
 static int noauto = 0;
+
+#ifdef module_param
+module_param(debug_crypto,int,0600)
+module_param(test_crypto,int,0600)
+module_param(excl_crypto,int,0600)
+
+module_param(debug_crypto,int,0600)
+#else
+MODULE_PARM(debug_crypto, "i");
+MODULE_PARM(test_crypto, "i");
+MODULE_PARM(excl_crypto, "i");
+
 MODULE_PARM(noauto,"i");
+#endif
 MODULE_PARM_DESC(noauto, "Dont try all known algos, just setup enabled ones");
 
+#ifdef CONFIG_KLIPS_ENC_1DES
+static int des_ede1[] = {-1, -1};
+#endif
 static int des_ede3[] = {-1, -1};
 static int aes[] = {-1, -1};
 static int blowfish[] = {-1, -1};
@@ -116,12 +126,29 @@ static int cast[] = {-1, -1};
 static int serpent[] = {-1, -1};
 static int twofish[] = {-1, -1};
 
+#ifdef CONFIG_KLIPS_ENC_1DES
+#ifdef module_param
+module_param_array(des_ede1,int,NULL,0)
+#else
+MODULE_PARM(des_ede1,"1-2i");
+#endif
+#endif
+#ifdef module_param
+module_param_array(des_ede3,int,NULL,0)
+module_param_array(aes,int,NULL,0)
+module_param_array(blowfish,int,NULL,0)
+module_param_array(cast,int,NULL,0)
+module_param_array(serpent,int,NULL,0)
+module_param_array(twofish,int,NULL,0)
+
 MODULE_PARM(des_ede3,"1-2i");
 MODULE_PARM(aes,"1-2i");
 MODULE_PARM(blowfish,"1-2i");
 MODULE_PARM(cast,"1-2i");
 MODULE_PARM(serpent,"1-2i");
 MODULE_PARM(twofish,"1-2i");
+#endif
+MODULE_PARM_DESC(des_ede1, "0: disable | 1: force_enable | min,max: dontuse");
 MODULE_PARM_DESC(des_ede3, "0: disable | 1: force_enable | min,max: dontuse");
 MODULE_PARM_DESC(aes, "0: disable | 1: force_enable | min,max: keybitlens");
 MODULE_PARM_DESC(blowfish, "0: disable | 1: force_enable | min,max: keybitlens");
@@ -137,15 +164,20 @@ struct ipsec_alg_capi_cipher {
 	int *parm;		/* lkm param for this cipher */
 	struct ipsec_alg_enc alg;	/* note it's not a pointer */
 };
+
 static struct ipsec_alg_capi_cipher alg_capi_carray[] = {
-	{ CIPHERNAME_AES ,     16, 128, 256, aes    , { ixt_alg_id: ESP_AES, }},
-	{ CIPHERNAME_TWOFISH , 16, 128, 256, twofish, { ixt_alg_id: ESP_TWOFISH, }},
-	{ CIPHERNAME_SERPENT , 16, 128, 256, serpent, { ixt_alg_id: ESP_SERPENT, }},
-	{ CIPHERNAME_CAST ,     8, 128, 128, cast   , { ixt_alg_id: ESP_CAST, }},
-	{ CIPHERNAME_BLOWFISH , 8,  96, 448, blowfish,{ ixt_alg_id: ESP_BLOWFISH, }},
-	{ CIPHERNAME_3DES ,     8, 192, 192, des_ede3,{ ixt_alg_id: ESP_3DES, }},
-	{ NULL, 0, 0, 0, NULL, {} }
+  { CIPHERNAME_AES,     16, 128, 256, aes,      { ixt_common:{ ixt_support:{ ias_id: ESP_AES}}}},
+  { CIPHERNAME_TWOFISH, 16, 128, 256, twofish,  { ixt_common:{ ixt_support:{ ias_id: ESP_TWOFISH,}}}},
+  { CIPHERNAME_SERPENT, 16, 128, 256, serpent,  { ixt_common:{ ixt_support:{ ias_id: ESP_SERPENT,}}}},
+  { CIPHERNAME_CAST,     8, 128, 128, cast   ,  { ixt_common:{ ixt_support:{ ias_id: ESP_CAST,}}}},
+  { CIPHERNAME_BLOWFISH, 8,  96, 448, blowfish, { ixt_common:{ ixt_support:{ ias_id: ESP_BLOWFISH,}}}},
+  { CIPHERNAME_3DES,     8, 192, 192, des_ede3, { ixt_common:{ ixt_support:{ ias_id: ESP_3DES,}}}},
+#ifdef CONFIG_KLIPS_ENC_1DES
+  { CIPHERNAME_1DES,     8,  64,  64, des_ede1, { ixt_common:{ ixt_support:{ ias_id: ESP_DES,}}}},
+#endif
+  { NULL, 0, 0, 0, NULL, {} }
 };
+
 #ifdef NOT_YET
 struct ipsec_alg_capi_digest {
 	const char *digestname;	/* cryptoapi's digestname */
@@ -178,34 +210,34 @@ static int
 setup_ipsec_alg_capi_cipher(struct ipsec_alg_capi_cipher *cptr)
 {
 	int ret;
-	cptr->alg.ixt_version = IPSEC_ALG_VERSION;
-	cptr->alg.ixt_module = THIS_MODULE;
-	atomic_set (& cptr->alg.ixt_refcnt, 0);
-	strncpy (cptr->alg.ixt_name , cptr->ciphername, sizeof (cptr->alg.ixt_name));
+	cptr->alg.ixt_common.ixt_version = IPSEC_ALG_VERSION;
+	cptr->alg.ixt_common.ixt_module  = THIS_MODULE;
+	atomic_set (& cptr->alg.ixt_common.ixt_refcnt, 0);
+	strncpy (cptr->alg.ixt_common.ixt_name , cptr->ciphername, sizeof (cptr->alg.ixt_common.ixt_name));
 
-	cptr->alg.ixt_blocksize=cptr->blocksize;
-	cptr->alg.ixt_keyminbits=cptr->minbits;
-	cptr->alg.ixt_keymaxbits=cptr->maxbits;
-	cptr->alg.ixt_state = 0;
-	if (excl) cptr->alg.ixt_state |= IPSEC_ALG_ST_EXCL;
-	cptr->alg.ixt_e_keylen=cptr->alg.ixt_keymaxbits/8;
+	cptr->alg.ixt_common.ixt_blocksize=cptr->blocksize;
+	cptr->alg.ixt_common.ixt_support.ias_keyminbits=cptr->minbits;
+	cptr->alg.ixt_common.ixt_support.ias_keymaxbits=cptr->maxbits;
+	cptr->alg.ixt_common.ixt_state = 0;
+	if (excl_crypto) cptr->alg.ixt_common.ixt_state |= IPSEC_ALG_ST_EXCL;
+	cptr->alg.ixt_e_keylen=cptr->alg.ixt_common.ixt_support.ias_keymaxbits/8;
 	cptr->alg.ixt_e_ctx_size = 0;
-	cptr->alg.ixt_alg_type = IPSEC_ALG_TYPE_ENCRYPT;
+	cptr->alg.ixt_common.ixt_support.ias_exttype = IPSEC_ALG_TYPE_ENCRYPT;
 	cptr->alg.ixt_e_new_key = _capi_new_key;
 	cptr->alg.ixt_e_destroy_key = _capi_destroy_key;
 	cptr->alg.ixt_e_cbc_encrypt = _capi_cbc_encrypt;
-	cptr->alg.ixt_data = cptr;
+	cptr->alg.ixt_common.ixt_data = cptr;
 
 	ret=register_ipsec_alg_enc(&cptr->alg);
-	printk("setup_ipsec_alg_capi_cipher(): " 
+	printk(KERN_INFO "KLIPS cryptoapi interface: " 
 			"alg_type=%d alg_id=%d name=%s "
-			"keyminbits=%d keymaxbits=%d, ret=%d\n", 
-				cptr->alg.ixt_alg_type, 
-				cptr->alg.ixt_alg_id, 
-				cptr->alg.ixt_name, 
-				cptr->alg.ixt_keyminbits,
-				cptr->alg.ixt_keymaxbits,
-				ret);
+			"keyminbits=%d keymaxbits=%d, %s(%d)\n", 
+				cptr->alg.ixt_common.ixt_support.ias_exttype, 
+				cptr->alg.ixt_common.ixt_support.ias_id, 
+				cptr->alg.ixt_common.ixt_name, 
+				cptr->alg.ixt_common.ixt_support.ias_keyminbits,
+				cptr->alg.ixt_common.ixt_support.ias_keymaxbits,
+	       ret ? "not found" : "found", ret);
 	return ret;
 }
 /*
@@ -217,14 +249,14 @@ _capi_destroy_key (struct ipsec_alg_enc *alg, __u8 *key_e)
 {
 	struct crypto_tfm *tfm=(struct crypto_tfm*)key_e;
 	
-	if (debug > 0)
+	if (debug_crypto > 0)
 		printk(KERN_DEBUG "klips_debug: _capi_destroy_key:"
 				"name=%s key_e=%p \n",
-				alg->ixt_name, key_e);
+				alg->ixt_common.ixt_name, key_e);
 	if (!key_e) {
 		printk(KERN_ERR "klips_debug: _capi_destroy_key:"
 				"name=%s NULL key_e!\n",
-				alg->ixt_name);
+				alg->ixt_common.ixt_name);
 		return;
 	}
 	crypto_free_tfm(tfm);
@@ -240,17 +272,17 @@ _capi_new_key (struct ipsec_alg_enc *alg, const __u8 *key, size_t keylen)
 	struct ipsec_alg_capi_cipher *cptr;
 	struct crypto_tfm *tfm=NULL;
 
-	cptr = alg->ixt_data;
+	cptr = alg->ixt_common.ixt_data;
 	if (!cptr) {
 		printk(KERN_ERR "_capi_new_key(): "
 				"NULL ixt_data (?!) for \"%s\" algo\n" 
-				, alg->ixt_name);
+				, alg->ixt_common.ixt_name);
 		goto err;
 	}
-	if (debug > 0)
+	if (debug_crypto > 0)
 		printk(KERN_DEBUG "klips_debug:_capi_new_key:"
 				"name=%s cptr=%p key=%p keysize=%d\n",
-				alg->ixt_name, cptr, key, keylen);
+				alg->ixt_common.ixt_name, cptr, key, keylen);
 	
 	/*	
 	 *	alloc tfm
@@ -259,21 +291,21 @@ _capi_new_key (struct ipsec_alg_enc *alg, const __u8 *key, size_t keylen)
 	if (!tfm) {
 		printk(KERN_ERR "_capi_new_key(): "
 				"NULL tfm for \"%s\" cryptoapi (\"%s\") algo\n" 
-			, alg->ixt_name, cptr->ciphername);
+			, alg->ixt_common.ixt_name, cptr->ciphername);
 		goto err;
 	}
 	if (crypto_cipher_setkey(tfm, key, keylen) < 0) {
 		printk(KERN_ERR "_capi_new_key(): "
 				"failed new_key() for \"%s\" cryptoapi algo (keylen=%d)\n" 
-			, alg->ixt_name, keylen);
+			, alg->ixt_common.ixt_name, keylen);
 		crypto_free_tfm(tfm);
 		tfm=NULL;
 	}
 err:
-	if (debug > 0)
+	if (debug_crypto > 0)
 		printk(KERN_DEBUG "klips_debug:_capi_new_key:"
 				"name=%s key=%p keylen=%d tfm=%p\n",
-				alg->ixt_name, key, keylen, tfm);
+				alg->ixt_common.ixt_name, key, keylen, tfm);
 	return (__u8 *) tfm;
 }
 /*
@@ -289,7 +321,7 @@ _capi_cbc_encrypt(struct ipsec_alg_enc *alg, __u8 * key_e, __u8 * in, int ilen,
 		.offset = (unsigned long)(in) % PAGE_SIZE,
 		.length=ilen,
 	};
-	if (debug > 1)
+	if (debug_crypto > 1)
 		printk(KERN_DEBUG "klips_debug:_capi_cbc_encrypt:"
 				"key_e=%p "
 				"in=%p out=%p ilen=%d iv=%p encrypt=%d\n"
@@ -300,7 +332,7 @@ _capi_cbc_encrypt(struct ipsec_alg_enc *alg, __u8 * key_e, __u8 * in, int ilen,
 		error = crypto_cipher_encrypt (tfm, &sg, &sg, ilen);
 	else
 		error = crypto_cipher_decrypt (tfm, &sg, &sg, ilen);
-	if (debug > 1)
+	if (debug_crypto > 1)
 		printk(KERN_DEBUG "klips_debug:_capi_cbc_encrypt:"
 				"error=%d\n"
 				, error);
@@ -322,7 +354,7 @@ setup_cipher_list (struct ipsec_alg_capi_cipher* clist)
 		 * if noauto set and not enabled (1)
 		 */
 		if (cptr->parm[0] == 0 || (noauto && cptr->parm[0] < 0)) {
-			if (debug>0)
+			if (debug_crypto>0)
 				printk(KERN_INFO "setup_cipher_list(): "
 					"ciphername=%s skipped at user request: "
 					"noauto=%d parm[0]=%d parm[1]=%d\n"
@@ -336,25 +368,26 @@ setup_cipher_list (struct ipsec_alg_capi_cipher* clist)
 		 * 	use a local ci to avoid touching cptr->ci,
 		 * 	if register ipsec_alg success then bind cipher
 		 */
+		if(cptr->alg.ixt_common.ixt_support.ias_name == NULL) {
+		  cptr->alg.ixt_common.ixt_support.ias_name = cptr->ciphername;
+		}
+
 		if( setup_cipher(cptr->ciphername) ) {
-			if (debug > 0)
+			if (debug_crypto > 0)
 				printk(KERN_DEBUG "klips_debug:"
 						"setup_cipher_list():"
 						"ciphername=%s found\n"
 				, cptr->ciphername);
-			if (setup_ipsec_alg_capi_cipher(cptr) == 0) {
-				
-				
-			} else {
+
+			if (setup_ipsec_alg_capi_cipher(cptr) != 0) {
 				printk(KERN_ERR "klips_debug:"
-						"setup_cipher_list():"
-						"ciphername=%s failed ipsec_alg_register\n"
-				, cptr->ciphername);
+				       "setup_cipher_list():"
+				       "ciphername=%s failed ipsec_alg_register\n"
+				       , cptr->ciphername);
 			}
 		} else {
-			if (debug>0)
-				printk(KERN_INFO "setup_cipher_list(): lookup for ciphername=%s: not found \n",
-				cptr->ciphername);
+			printk(KERN_INFO "KLIPS: lookup for ciphername=%s: not found \n",
+			       cptr->ciphername);
 		}
 	}
 	return 0;
@@ -368,7 +401,7 @@ unsetup_cipher_list (struct ipsec_alg_capi_cipher* clist)
 	struct ipsec_alg_capi_cipher *cptr;
 	/* foreach cipher in list ... */
 	for (cptr=clist;cptr->ciphername;cptr++) {
-		if (cptr->alg.ixt_state & IPSEC_ALG_ST_REGISTERED) {
+		if (cptr->alg.ixt_common.ixt_state & IPSEC_ALG_ST_REGISTERED) {
 			unregister_ipsec_alg_enc(&cptr->alg);
 		}
 	}
@@ -384,15 +417,15 @@ test_cipher_list (struct ipsec_alg_capi_cipher* clist)
 	struct ipsec_alg_capi_cipher *cptr;
 	/* foreach cipher in list ... */
 	for (cptr=clist;cptr->ciphername;cptr++) {
-		if (cptr->alg.ixt_state & IPSEC_ALG_ST_REGISTERED) {
+		if (cptr->alg.ixt_common.ixt_state & IPSEC_ALG_ST_REGISTERED) {
 			test_ret=ipsec_alg_test(
-					cptr->alg.ixt_alg_type,
-					cptr->alg.ixt_alg_id, 
-					test);
+					cptr->alg.ixt_common.ixt_support.ias_exttype,
+					cptr->alg.ixt_common.ixt_support.ias_id, 
+					test_crypto);
 			printk("test_cipher_list(alg_type=%d alg_id=%d): test_ret=%d\n", 
-					cptr->alg.ixt_alg_type, 
-					cptr->alg.ixt_alg_id, 
-					test_ret);
+			       cptr->alg.ixt_common.ixt_support.ias_exttype, 
+			       cptr->alg.ixt_common.ixt_support.ias_id,
+			       test_ret);
 		}
 	}
 	return 0;
@@ -403,7 +436,7 @@ IPSEC_ALG_MODULE_INIT_STATIC( ipsec_cryptoapi_init )
 	int ret, test_ret;
 	if ((ret=setup_cipher_list(alg_capi_carray)) < 0)
 		return  -EPROTONOSUPPORT;
-	if (ret==0 && test) {
+	if (ret==0 && test_crypto) {
 		test_ret=test_cipher_list(alg_capi_carray);
 	}
 	return ret;
@@ -417,5 +450,4 @@ IPSEC_ALG_MODULE_EXIT_STATIC( ipsec_cryptoapi_fini )
 MODULE_LICENSE("GPL");
 #endif
 
-EXPORT_NO_SYMBOLS;
 #endif /* NO_CRYPTOAPI_SUPPORT */
