@@ -13,7 +13,7 @@
  * for more details.
  */
 
-char ipsec_ipcomp_c_version[] = "RCSID $Id: ipsec_ipcomp.c,v 1.5 2005/04/29 05:10:22 mcr Exp $";
+char ipsec_ipcomp_c_version[] = "RCSID $Id: ipsec_ipcomp.c,v 1.5.2.1 2006/07/07 16:39:58 paul Exp $";
 #include <linux/config.h>
 #include <linux/version.h>
 
@@ -77,7 +77,7 @@ ipsec_rcv_ipcomp_checks(struct ipsec_rcv_state *irs,
 {
 	int ipcompminlen;
 
-	ipcompminlen = irs->hard_header_len + sizeof(struct iphdr);
+	ipcompminlen = sizeof(struct iphdr);
 
 	if(skb->len < (ipcompminlen + sizeof(struct ipcomphdr))) {
 		KLIPS_PRINT(debug_rcv & DB_RX_INAU,
