@@ -14,7 +14,7 @@
  * for more details.
  */
 
-char ipsec_tunnel_c_version[] = "RCSID $Id: ipsec_tunnel.c,v 1.232 2005/06/04 16:06:06 mcr Exp $";
+char ipsec_tunnel_c_version[] = "RCSID $Id: ipsec_tunnel.c,v 1.232.2.4 2006/03/28 20:58:19 ken Exp $";
 
 #define __NO_VERSION__
 #include <linux/module.h>
@@ -61,6 +61,7 @@ char ipsec_tunnel_c_version[] = "RCSID $Id: ipsec_tunnel.c,v 1.232 2005/06/04 16
 #endif /* NETDEV_23 */
 
 #include <linux/if_arp.h>
+#include <net/arp.h>
 
 #include "openswan/ipsec_kversion.h"
 #include "openswan/radij.h"
@@ -272,15 +273,20 @@ ipsec_tunnel_SAlookup(struct ipsec_xmit_state *ixs)
 
 		if(ixs->skb->sk) {
 #ifdef NET_26
-			struct tcp_tw_bucket *tw;
-			
-			tw = (struct tcp_tw_bucket *)ixs->skb->sk;
-
-			ixs->sport = ntohs(tw->tw_sport);
-			ixs->dport = ntohs(tw->tw_dport);
+#ifdef HAVE_INET_SK_SPORT
+                       ixs->sport = ntohs(inet_sk(ixs->skb->sk)->sport);
+                       ixs->dport = ntohs(inet_sk(ixs->skb->sk)->dport);
 #else
-			ixs->sport = ntohs(ixs->skb->sk->sport);
-			ixs->dport = ntohs(ixs->skb->sk->dport);
+                        struct tcp_tw_bucket *tw;
+
+                        tw = (struct tcp_tw_bucket *)ixs->skb->sk;
+
+                        ixs->sport = ntohs(tw->tw_sport);
+                        ixs->dport = ntohs(tw->tw_dport);
+#endif
+#else
+                        ixs->sport = ntohs(ixs->skb->sk->sport);
+                        ixs->dport = ntohs(ixs->skb->sk->dport);
 #endif
 		} 
 
@@ -560,6 +566,7 @@ ipsec_tunnel_send(struct ipsec_xmit_state*ixs)
 	/* new route/dst cache code from James Morris */
 	ixs->skb->dev = ixs->physdev;
 #ifdef NETDEV_25
+	memset (&fl, 0x0, sizeof (struct flowi));
  	fl.oif = ixs->physdev->iflink;
  	fl.nl_u.ip4_u.daddr = ixs->skb->nh.iph->daddr;
  	fl.nl_u.ip4_u.saddr = ixs->pass ? 0 : ixs->skb->nh.iph->saddr;
@@ -611,7 +618,7 @@ ipsec_tunnel_send(struct ipsec_xmit_state*ixs)
 	  nf_conntrack_put(ixs->skb->nfct);
 	  ixs->skb->nfct = NULL;
 	}
-#ifdef CONFIG_NETFILTER_DEBUG
+#if defined(CONFIG_NETFILTER_DEBUG) && defined(HAVE_SKB_NF_DEBUG)
 	ixs->skb->nf_debug = 0;
 #endif /* CONFIG_NETFILTER_DEBUG */
 #endif /* SKB_RESET_NFCT */
@@ -1839,6 +1846,24 @@ ipsec_tunnel_cleanup_devices(void)
 
 /*
  * $Log: ipsec_tunnel.c,v $
+ * Revision 1.232.2.4  2006/03/28 20:58:19  ken
+ * Fix for KLIPS on 2.6.16 - need to include <net/arp.h> now
+ *
+ * Revision 1.232.2.3  2006/02/15 05:14:12  paul
+ * 568: uninitialized struct in ipsec_tunnel.c coud break routing under 2.6 kernels
+ * ipsec_tunnel_send() calls the entry point function of routing subsystem
+ * (ip_route_output_key()) using a not fully initialized struct of type
+ * struct flowi.
+ * This will cause a failure in routing packets through an ipsec interface
+ * when patches for multipath routing from http://www.ssi.bg/~ja/
+ * are applied.
+ *
+ * Revision 1.232.2.2  2005/11/22 04:11:52  ken
+ * Backport fixes for 2.6.14 kernels from HEAD
+ *
+ * Revision 1.232.2.1  2005/09/21 22:57:43  paul
+ * pulled up compile fix for 2.6.13
+ *
  * Revision 1.232  2005/06/04 16:06:06  mcr
  * 	better patch for nat-t rcv-device code.
  *
