@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: pfkey_v2.c,v 1.97.2.7 2006/04/04 11:34:19 ken Exp $
+ * RCSID $Id: pfkey_v2.c,v 1.97.2.8 2006/07/10 15:56:11 paul Exp $
  */
 
 /*
@@ -84,8 +84,8 @@ extern int sysctl_ipsec_debug_verbose;
 #define SOCKOPS_WRAPPED(name) name
 #endif /* SOCKOPS_WRAPPED */
 
-static rwlock_t pfkey_sock_lock = RW_LOCK_UNLOCKED;
 #ifdef NET_26
+static rwlock_t pfkey_sock_lock = RW_LOCK_UNLOCKED;
 HLIST_HEAD(pfkey_sock_list);
 static DECLARE_WAIT_QUEUE_HEAD(pfkey_sock_wait);
 static atomic_t pfkey_sock_users = ATOMIC_INIT(0);
@@ -1541,6 +1541,7 @@ cleanup_module(void)
 }
 #endif /* 0 */
 #else /* MODULE */
+struct net_protocol;
 void pfkey_proto_init(struct net_protocol *pro)
 {
 	pfkey_init();
@@ -1549,6 +1550,9 @@ void pfkey_proto_init(struct net_protocol *pro)
 
 /*
  * $Log: pfkey_v2.c,v $
+ * Revision 1.97.2.8  2006/07/10 15:56:11  paul
+ * Fix for bug #642 by Bart.
+ *
  * Revision 1.97.2.7  2006/04/04 11:34:19  ken
  * Backport SMP fixes + #ifdef cleanup from #public
  *
