@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
  * License for more details.
  *
- * RCSID $Id: config-all.h,v 1.11 2005/01/26 00:52:59 mcr Exp $
+ * RCSID $Id: config-all.h,v 1.11.6.3 2006/03/22 03:50:17 paul Exp $
  */
 #define	_CONFIG_ALL_H_	/* seen it, no need to see it again */
 
@@ -54,8 +54,10 @@
 #define CONFIG_KLIPS_ENC_3DES 1
 #endif
 
+#if 0
 #ifndef CONFIG_IPSEC_NAT_TRAVERSAL
-#define CONFIG_IPSEC_NAT_TRAVERSAL 1
+#define CONFIG_IPSEC_NAT_TRAVERSAL 0
+#endif
 #endif
 
 #ifndef CONFIG_KLIPS_ENC_AES
@@ -68,10 +70,10 @@
 #endif
 
 #define CONFIG_KLIPS_ALG_CRYPTOAPI #error
-#define CONFIG_KLIPS_ALG_AES #error
+#define CONFIG_IPSEC_ALG_AES #error
 
-#ifndef CONFIG_KLIPS_ALG_AES_MAC
-#define CONFIG_KLIPS_ALG_AES_MAC 1
+#ifndef CONFIG_IPSEC_ALG_AES_MAC
+#define CONFIG_IPSEC_ALG_AES_MAC 1
 #endif
 
 #ifndef CONFIG_KLIPS_REGRESS
