@@ -14,13 +14,14 @@
  * for more details.
  */
 
-char eroute_c_version[] = "RCSID $Id: eroute.c,v 1.61 2004/12/10 12:38:29 paul Exp $";
+char eroute_c_version[] = "RCSID $Id: eroute.c,v 1.66.2.1 2005/08/18 14:04:51 ken Exp $";
 
 
 #include <sys/types.h>
 #include <linux/types.h> /* new */
 #include <string.h>
 #include <errno.h>
+#include <sys/wait.h>
 #include <stdlib.h> /* system(), strtoul() */
 
 #include <sys/socket.h>
@@ -459,8 +460,14 @@ main(int argc, char **argv)
                         exit(1);
                 }
                 else {
-                        system("cat /proc/net/ipsec_eroute");
-                        exit(0);
+			int ret = 1;
+			if ((stat ("/proc/net/ipsec_eroute", &sts)) != 0)  {
+				fprintf(stderr, "%s: No eroute table - no IPsec support in kernel (are the modules loaded?)\n", program_name);
+			} else {
+				int ret = system("cat /proc/net/ipsec_eroute");
+				ret = ret != -1 && WIFEXITED(ret) ? WEXITSTATUS(ret) : 1;
+			}
+			exit(ret);
                 }
         }
 	
@@ -904,6 +911,24 @@ main(int argc, char **argv)
 }
 /*
  * $Log: eroute.c,v $
+ * Revision 1.66.2.1  2005/08/18 14:04:51  ken
+ * Patch from mt@suse.de to avoid GCC warnings with system() calls
+ *
+ * Revision 1.66  2005/07/08 02:56:38  paul
+ * gcc4 fixes that were not commited because vault was down
+ *
+ * Revision 1.65  2005/03/22 23:14:54  ken
+ * *** empty log message ***
+ *
+ * Revision 1.64  2005/03/22 23:14:06  ken
+ * Fix logic
+ *
+ * Revision 1.63  2005/03/22 23:06:13  ken
+ * Fix sloppy typo
+ *
+ * Revision 1.62  2005/03/22 23:02:37  ken
+ * Nicer error messages - #234
+ *
  * Revision 1.61  2004/12/10 12:38:29  paul
  * Renamed the stack names consistently to KLIPS and NETKEY
  *
