@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: crypto.h,v 1.19 2004/11/25 18:19:31 mcr Exp $
+ * RCSID $Id: crypto.h,v 1.21 2005/07/05 22:05:02 mcr Exp $
  */
 
 #include <gmp.h>    /* GNU MP library */
@@ -51,7 +51,7 @@ struct state;	/* forward declaration, dammit */
 struct encrypt_desc;
 struct hash_desc;
 struct encrypt_desc *crypto_get_encrypter(int alg);
-struct hash_desc *crypto_get_hasher(int alg);
+struct hash_desc *crypto_get_hasher(oakley_hash_t alg);
 void crypto_cbc_encrypt(const struct encrypt_desc *e, bool enc, u_int8_t *buf, size_t size, struct state *st);
 
 #define update_iv(st)	passert(st->st_new_iv_len <= sizeof(st->st_iv)); memcpy((st)->st_iv, (st)->st_new_iv \
@@ -69,6 +69,8 @@ void crypto_cbc_encrypt(const struct encrypt_desc *e, bool enc, u_int8_t *buf, s
 union hash_ctx {
 	MD5_CTX ctx_md5;
 	SHA1_CTX ctx_sha1;
+	char ctx_sha256[108];   /* This is _ugly_ [TM], but avoids */
+	char ctx_sha512[212];   /* header coupling (is checked at runtime */
     };
 
 
