@@ -1,6 +1,6 @@
 /* Dynamic fetching of X.509 CRLs
  * Copyright (C) 2002 Stephane Laroche <stephane.laroche@colubris.com>
- * Copyright (C) 2000-2003 Andreas Steffen, Zuercher Hochschule Winterthur
+ * Copyright (C) 2002-2004 Andreas Steffen, Zuercher Hochschule Winterthur
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: fetch.c,v 1.2.6.1 2004/03/21 05:23:32 mcr Exp $
+ * RCSID $Id: fetch.c,v 1.6 2004/06/14 02:01:32 mcr Exp $
  */
 
 #include <stdlib.h>
@@ -21,6 +21,10 @@
 #include <pthread.h>
 #include <string.h>
 
+#ifdef LIBCURL
+#include <curl/curl.h>
+#endif
+
 #include <openswan.h>
 
 #ifdef LDAP_VER
@@ -35,10 +39,16 @@
 #include "pem.h"
 #include "x509.h"
 #include "whack.h"
+#include "ocsp.h"
 #include "fetch.h"
 
-#define FETCH_CMD	"curl -B"
-#define FETCH_CMD_TIMEOUT	4	/* seconds */
+#ifdef LIBCURL
+#define LIBCURL_UNUSED 
+#else
+#define LIBCURL_UNUSED UNUSED
+#endif
+
+#define FETCH_CMD_TIMEOUT	5	/* seconds */
 
 typedef struct fetch_req fetch_req_t;
 
@@ -50,9 +60,6 @@ struct fetch_req {
   generalName_t *distributionPoints;
 };
 
-/* chained list of fetch requests */
-static fetch_req_t *fetch_reqs  = NULL;
-
 fetch_req_t empty_fetch_req = {
    NULL    , /* next */
          0 , /* installed */
@@ -61,37 +68,70 @@ fetch_req_t empty_fetch_req = {
    NULL      /* distributionPoints */
 };
 
+/* chained list of crl fetch requests */
+static fetch_req_t *crl_fetch_reqs  = NULL;
+
+/* chained list of ocsp fetch requests */
+static ocsp_location_t *ocsp_fetch_reqs = NULL;
+
 static pthread_t thread;
-static pthread_mutex_t cacert_list_mutex = PTHREAD_MUTEX_INITIALIZER;
-static pthread_mutex_t crl_list_mutex =    PTHREAD_MUTEX_INITIALIZER;
-static pthread_mutex_t fetch_list_mutex =  PTHREAD_MUTEX_INITIALIZER;
-static pthread_mutex_t fetch_wake_mutex =  PTHREAD_MUTEX_INITIALIZER;
-static pthread_cond_t fetch_wake_cond =    PTHREAD_COND_INITIALIZER;
+static pthread_mutex_t certs_and_keys_mutex  = PTHREAD_MUTEX_INITIALIZER;
+static pthread_mutex_t authcert_list_mutex   = PTHREAD_MUTEX_INITIALIZER;
+static pthread_mutex_t crl_list_mutex        = PTHREAD_MUTEX_INITIALIZER;
+static pthread_mutex_t ocsp_cache_mutex      = PTHREAD_MUTEX_INITIALIZER;
+static pthread_mutex_t crl_fetch_list_mutex  = PTHREAD_MUTEX_INITIALIZER;
+static pthread_mutex_t ocsp_fetch_list_mutex = PTHREAD_MUTEX_INITIALIZER;
+static pthread_mutex_t fetch_wake_mutex      = PTHREAD_MUTEX_INITIALIZER;
+static pthread_cond_t  fetch_wake_cond       = PTHREAD_COND_INITIALIZER;
 
 #define BUF_LEN		512
 
 /*
- * lock access to the chained cacert list
+ * lock access to my certs and keys
  */
 void
-lock_cacert_list(const char *who)
+lock_certs_and_keys(const char *who)
 {
-    pthread_mutex_lock(&cacert_list_mutex);
-    DBG(DBG_CONTROL,
-	DBG_log("cacert list locked by '%s'", who)
+    pthread_mutex_lock(&certs_and_keys_mutex);
+    DBG(DBG_CONTROLMORE,
+	DBG_log("certs and keys locked by '%s'", who)
     )
 }
 
 /*
- * unlock access to the chained cacert list
+ * unlock access to my certs and keys
  */
 void
-unlock_cacert_list(const char *who)
+unlock_certs_and_keys(const char *who)
 {
-    DBG(DBG_CONTROL,
-	DBG_log("cacert list unlocked by '%s'", who)
+    DBG(DBG_CONTROLMORE,
+	DBG_log("certs and keys unlocked by '%s'", who)
     )
-    pthread_mutex_unlock(&cacert_list_mutex);
+    pthread_mutex_unlock(&certs_and_keys_mutex);
+}
+
+/*
+ * lock access to the chained authcert list
+ */
+void
+lock_authcert_list(const char *who)
+{
+    pthread_mutex_lock(&authcert_list_mutex);
+    DBG(DBG_CONTROLMORE,
+	DBG_log("authcert list locked by '%s'", who)
+    )
+}
+
+/*
+ * unlock access to the chained authcert list
+ */
+void
+unlock_authcert_list(const char *who)
+{
+    DBG(DBG_CONTROLMORE,
+	DBG_log("authcert list unlocked by '%s'", who)
+    )
+    pthread_mutex_unlock(&authcert_list_mutex);
 }
 
 /*
@@ -101,7 +141,7 @@ void
 lock_crl_list(const char *who)
 {
     pthread_mutex_lock(&crl_list_mutex);
-    DBG(DBG_CONTROL,
+    DBG(DBG_CONTROLMORE,
 	DBG_log("crl list locked by '%s'", who)
     )
 }
@@ -112,34 +152,82 @@ lock_crl_list(const char *who)
 void
 unlock_crl_list(const char *who)
 {
-    DBG(DBG_CONTROL,
+    DBG(DBG_CONTROLMORE,
 	DBG_log("crl list unlocked by '%s'", who)
     )
     pthread_mutex_unlock(&crl_list_mutex);
 }
 
 /*
- * lock access to the chained fetch request list
+ * lock access to the ocsp cache
  */
-static void
-lock_fetch_list(const char *who)
+extern void
+lock_ocsp_cache(const char *who)
 {
-    pthread_mutex_lock(&fetch_list_mutex);
-    DBG(DBG_CONTROL,
-	DBG_log("fetch request list locked by '%s'", who)
+    pthread_mutex_lock(&ocsp_cache_mutex);
+    DBG(DBG_CONTROLMORE,
+	DBG_log("ocsp cache locked by '%s'", who)
     )
 }
 
 /*
- * unlock access to the chained fetch request list
+ * unlock access to the ocsp cache
+ */
+extern void
+unlock_ocsp_cache(const char *who)
+{
+    DBG(DBG_CONTROLMORE,
+	DBG_log("ocsp cache unlocked by '%s'", who)
+    )
+    pthread_mutex_unlock(&ocsp_cache_mutex);
+}
+
+/*
+ * lock access to the chained crl fetch request list
  */
 static void
-unlock_fetch_list(const char *who)
+lock_crl_fetch_list(const char *who)
 {
-    DBG(DBG_CONTROL,
-	DBG_log("fetch request list unlocked by '%s'", who)
+    pthread_mutex_lock(&crl_fetch_list_mutex);
+    DBG(DBG_CONTROLMORE,
+	DBG_log("crl fetch request list locked by '%s'", who)
     )
-    pthread_mutex_unlock(&fetch_list_mutex);
+}
+
+/*
+ * unlock access to the chained crl fetch request list
+ */
+static void
+unlock_crl_fetch_list(const char *who)
+{
+    DBG(DBG_CONTROLMORE,
+	DBG_log("crl fetch request list unlocked by '%s'", who)
+    )
+    pthread_mutex_unlock(&crl_fetch_list_mutex);
+}
+
+/*
+ * lock access to the chained ocsp fetch request list
+ */
+static void
+lock_ocsp_fetch_list(const char *who)
+{
+    pthread_mutex_lock(&ocsp_fetch_list_mutex);
+    DBG(DBG_CONTROLMORE,
+	DBG_log("ocsp fetch request list locked by '%s'", who)
+    )
+}
+
+/*
+ * unlock access to the chained ocsp fetch request list
+ */
+static void
+unlock_ocsp_fetch_list(const char *who)
+{
+    DBG(DBG_CONTROLMORE,
+	DBG_log("ocsp fetch request list unlocked by '%s'", who)
+    )
+    pthread_mutex_unlock(&ocsp_fetch_list_mutex);
 }
 
 /*
@@ -150,12 +238,14 @@ wake_fetch_thread(const char *who)
 {
     if (crl_check_interval > 0)
     {
-	DBG(DBG_CONTROL,
+	DBG(DBG_CONTROLMORE,
 	    DBG_log("fetch thread wake call by '%s'", who)
 	)
+#ifdef HAVE_THREADS
 	pthread_mutex_lock(&fetch_wake_mutex);
 	pthread_cond_signal(&fetch_wake_cond);
 	pthread_mutex_unlock(&fetch_wake_mutex);
+#endif
     }
 }
 
@@ -170,114 +260,82 @@ free_fetch_request(fetch_req_t *req)
     pfree(req);
 }
 
-void
-free_fetch_requests(void)
+#ifdef LIBCURL
+/*
+ * writes data into a buffer
+ * needed for libcurl
+ */
+static size_t
+write_buffer(void *ptr, size_t size, size_t nmemb, void *data)
 {
-    lock_fetch_list("free_fetch_requests");
+    size_t realsize = size * nmemb;
+    chunk_t *mem = (chunk_t*)data;
 
-    while (fetch_reqs != NULL)
-    {
-	fetch_req_t *req = fetch_reqs;
-	fetch_reqs = req->next;
-	free_fetch_request(req);
+    mem->ptr = (u_char *)realloc(mem->ptr, mem->len + realsize);
+    if (mem->ptr) {
+        memcpy(&(mem->ptr[mem->len]), ptr, realsize);
+        mem->len += realsize;
     }
-
-    unlock_fetch_list("free_fetch_requests");
+    return realsize;
 }
+#endif
 
 /*
- * an url is not allowed to contain single quotes
+ * fetches a binary blob from a url with libcurl
  */
-static err_t
-clean_url(chunk_t url)
+static err_t 
+fetch_curl(chunk_t url LIBCURL_UNUSED, chunk_t *blob LIBCURL_UNUSED)
 {
-   if (memchr(url.ptr, '\'', url.len) != NULL)
-	return "url contains single quotes";
-   else
-	return NULL;
+#ifdef LIBCURL
+    char errorbuffer[CURL_ERROR_SIZE] = "";
+    char *uri;
+    chunk_t response = empty_chunk;
+    CURLcode res;  
+
+    /* get it with libcurl */
+    CURL *curl = curl_easy_init();
+
+    if (curl != NULL)
+    {
+        /* we need a null terminated string for curl */
+        uri = alloc_bytes(url.len + 1, "null terminated url");
+        memcpy(uri, url.ptr, url.len);
+        *(uri + url.len) = '\0';
+
+        DBG(DBG_CONTROL,
+            DBG_log("Trying cURL '%s'", uri)
+        )
+
+        curl_easy_setopt(curl, CURLOPT_URL, uri);
+        curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, write_buffer);
+        curl_easy_setopt(curl, CURLOPT_FILE, (void *)&response);
+        curl_easy_setopt(curl, CURLOPT_ERRORBUFFER, &errorbuffer);
+        curl_easy_setopt(curl, CURLOPT_CONNECTTIMEOUT, FETCH_CMD_TIMEOUT);
+
+
+        res = curl_easy_perform(curl);
+    
+        if (res == CURLE_OK)
+        {
+            blob->len = response.len;
+            blob->ptr = alloc_bytes(response.len, "curl blob");
+            memcpy(blob->ptr, response.ptr, response.len);
+        }
+        else
+        {
+            plog("fetching uri (%s) with libcurl failed: %s", uri, errorbuffer);
+        }
+        curl_easy_cleanup(curl);
+        pfree(uri);
+        /* not using freeanychunk because of realloc (no leak detective) */
+        free(response.ptr);
+    }
+    return strlen(errorbuffer) > 0 ? "libcurl error" : NULL;
+#else
+    return "not compiled with libcurl support";
+#endif   
 }
 
-/*
- * fetches a binary blob from a url via curl
- */
-static err_t
-fetch_curl(chunk_t url, chunk_t *blob)
-{
-    FILE *fp;
-    fd_set rfds;
-    size_t cmd_len;
-    char *cmd;
-
-    err_t ugh = clean_url(url);
-    if (ugh != NULL)
-	return ugh;
-
-    cmd_len = sizeof(FETCH_CMD) + url.len + 2;
-    cmd = alloc_bytes(cmd_len + 1, "curl cmd");
-    sprintf(cmd, "%s '%.*s'", FETCH_CMD, (int)url.len, url.ptr);
-
-    DBG(DBG_CONTROL,
-	DBG_log("executing %s", cmd)
-    )
-
-    /* Call curl to extract crl */
-    fp = popen(cmd, "r");
-    if (!fp)
-    {
-	ugh = "Executing curl command failed";
-    }
-    else
-    {
-	/* read from pipe and put in memory */
-	char *buf = NULL;
-	int len = 0;
-	int len2 = 0;
-	int retval = 0;
-	struct timeval timeout;
-
-	do {
-	    char *newbuf = realloc(buf, len+1024);
-	    if (!newbuf)
-	    {
-		free(buf);
-		break;
-	    }
-
-	    /* set timeout */
-	    timeout.tv_sec = FETCH_CMD_TIMEOUT;
-	    timeout.tv_usec = 0;
-
-	    FD_ZERO(&rfds);
-	    FD_SET(fileno(fp), &rfds);
-
-	    retval = select(fileno(fp)+1, &rfds, NULL, NULL, &timeout);
-	    if (retval > 0)
-	    {
-		buf = newbuf;
-		len2 = fread(buf+len, 1, 1024, fp);
-		len += len2;
-	    }
-	} while (retval > 0 && (len2 == 1024));
-
-	if (len > 0)
-	{
-	    blob->len = len;
-	    blob->ptr = alloc_bytes(len, "curl blob");
-	    memcpy(blob->ptr, buf, len);
-	}
-	else
-	{
-	    ugh = "Zero size blob fetched";
-	}
-	free(buf);
-    }
-
-    /* cleanup */
-    pclose(fp);
-    pfree(cmd);
-
-    return ugh;
-}
 
 #ifdef LDAP_VER
 /*
@@ -486,9 +544,9 @@ fetch_crls(void)
     fetch_req_t *req;
     fetch_req_t **reqp;
 
-    lock_fetch_list("fetch_crls");
-    req  =  fetch_reqs;
-    reqp = &fetch_reqs;
+    lock_crl_fetch_list("fetch_crls");
+    req  =  crl_fetch_reqs;
+    reqp = &crl_fetch_reqs;
 
     while (req != NULL)
     {
@@ -527,7 +585,7 @@ fetch_crls(void)
 
 	    req   = req->next;
 	    *reqp = req;
-	    free_fetch_request(req_free);	
+	    free_fetch_request(req_free);
 	}
 	else
 	{
@@ -537,7 +595,116 @@ fetch_crls(void)
 	    req  =  req->next;
 	}
     }
-    unlock_fetch_list("fetch_crls");
+    unlock_crl_fetch_list("fetch_crls");
+}
+
+static void
+fetch_ocsp_status(ocsp_location_t* location LIBCURL_UNUSED)
+{
+#ifdef LIBCURL
+    chunk_t request;
+    chunk_t response = empty_chunk;
+
+    CURL* curl;
+    CURLcode res;
+
+    request = build_ocsp_request(location);
+
+    DBG(DBG_CONTROL,
+    	DBG_log("sending ocsp request to location '%.*s'"
+	    , (int)location->uri.len, location->uri.ptr)
+    )
+    DBG(DBG_RAW,
+	DBG_dump_chunk("OCSP request", request)
+    )
+
+    /* send via http post using libcurl */
+    curl = curl_easy_init();
+
+    if (curl != NULL)
+    {
+	char errorbuffer[CURL_ERROR_SIZE];
+	struct curl_slist *headers = NULL;
+	char* uri = alloc_bytes(location->uri.len+1, "ocsp uri");
+
+	/* we need a null terminated string for curl */
+	memcpy(uri, location->uri.ptr, location->uri.len);
+	*(uri + location->uri.len) = '\0';
+
+	/* set content type header */
+	headers = curl_slist_append(headers, "Content-Type: application/ocsp-request");
+	curl_easy_setopt(curl, CURLOPT_HTTPHEADER, headers);
+
+	curl_easy_setopt(curl, CURLOPT_URL, uri);
+	curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, write_buffer);
+	curl_easy_setopt(curl, CURLOPT_FILE, (void *)&response);
+	curl_easy_setopt(curl, CURLOPT_POSTFIELDS, request.ptr);
+	curl_easy_setopt(curl, CURLOPT_POSTFIELDSIZE, request.len);
+	curl_easy_setopt(curl, CURLOPT_ERRORBUFFER, &errorbuffer);
+        curl_easy_setopt(curl, CURLOPT_CONNECTTIMEOUT, FETCH_CMD_TIMEOUT);
+
+
+	res = curl_easy_perform(curl);
+
+	if (res == CURLE_OK)
+	{
+	    DBG(DBG_CONTROL,
+		DBG_log("received ocsp response")
+	    )
+	    DBG(DBG_RAW,
+		DBG_dump_chunk("OCSP response", response)
+	    )
+	    parse_ocsp(location, response);
+	}
+	else
+	{
+	    plog("failed to fetch ocsp status (%s): %s", uri, errorbuffer);
+	}
+	curl_slist_free_all(headers);
+	curl_easy_cleanup(curl);
+	pfree(uri);
+	/* not using freeanychunk because of realloc (no leak detective) */
+	free(response.ptr);
+    }
+    freeanychunk(location->nonce);
+    freeanychunk(request);
+    
+    /* increment the trial counter of the unresolved fetch requests */
+    {
+	ocsp_certinfo_t *certinfo = location->certinfo;
+	
+	while (certinfo != NULL)
+	{
+	    certinfo->trials++;
+	    certinfo = certinfo->next;
+	}
+    }
+    return;
+#else
+    plog("ocsp error: pluto wasn't compiled with libcurl support");
+#endif
+}
+
+/*
+ * try to fetch the necessary ocsp information
+ */
+static void
+fetch_ocsp(void)
+{
+    ocsp_location_t *location;
+
+    lock_ocsp_fetch_list("fetch_ocsp");
+    location = ocsp_fetch_reqs;
+
+    /* fetch the ocps status for all locations */
+    while (location != NULL)
+    {
+	if (location->certinfo != NULL)
+	    fetch_ocsp_status(location);
+	location = location->next;
+    }
+
+    unlock_ocsp_fetch_list("fetch_ocsp");
 }
 
 static void*
@@ -549,8 +716,9 @@ fetch_thread(void *arg UNUSED)
 	DBG_log("fetch thread started")
     )
 
+#ifdef HAVE_THREADS
     pthread_mutex_lock(&fetch_wake_mutex);
-
+#endif
     while(1)
     {
 	int status;
@@ -568,8 +736,9 @@ fetch_thread(void *arg UNUSED)
 	{
 	    DBG(DBG_CONTROL,
 		DBG_log(" ");
-		DBG_log("*time to check crls")
+		DBG_log("*time to check crls and the ocsp cache")
 	    )
+	    check_ocsp();
 	    check_crls();
 	}
 	else
@@ -578,26 +747,72 @@ fetch_thread(void *arg UNUSED)
 		DBG_log("fetch thread was woken up")
 	    )
 	}
+	fetch_ocsp();
 	fetch_crls();
     }
 }
 
+/*
+ * initializes curl and starts the fetching thread
+ */
 void
-init_crl_fetch(void)
+init_fetch(void)
 {
     int status;
-
+    
     if (crl_check_interval > 0)
     {
-	status = pthread_create( &thread, NULL, fetch_thread, NULL);
-
+#ifdef LIBCURL
+	/* init curl */
+	status = curl_global_init(CURL_GLOBAL_NOTHING);
 	if (status != 0)
 	{
-	    plog("crl fetch thread could not be started, status = %d", status);
+	    plog("libcurl could not be initialized, status = %d", status);
+	}
+#endif
+	status = pthread_create( &thread, NULL, fetch_thread, NULL);
+	if (status != 0)
+	{
+	    plog("fetching thread could not be started, status = %d", status);
 	}
     }
 }
 
+void
+free_crl_fetch(void)
+{
+   lock_crl_fetch_list("free_crl_fetch");
+
+    while (crl_fetch_reqs != NULL)
+    {
+	fetch_req_t *req = crl_fetch_reqs;
+	crl_fetch_reqs = req->next;
+	free_fetch_request(req);
+    }
+
+    unlock_crl_fetch_list("free_crl_fetch");
+
+#ifdef LIBCURL
+    if (crl_check_interval > 0)
+    {
+	/* cleanup curl */
+	curl_global_cleanup();
+    }
+#endif
+}
+
+/*
+ * free the chained list of ocsp requests
+ */
+void
+free_ocsp_fetch(void)
+{
+    lock_ocsp_fetch_list("free_ocsp_fetch");
+    free_ocsp_locations(&ocsp_fetch_reqs);
+    unlock_ocsp_fetch_list("free_ocsp_fetch");
+}
+
+
 /*
  * add additional distribution points
  */
@@ -641,12 +856,12 @@ add_distribution_points(const generalName_t *newPoints ,generalName_t **distribu
  * add a crl fetch request to the chained list
  */
 void
-add_fetch_request(chunk_t issuer, const generalName_t *gn)
+add_crl_fetch_request(chunk_t issuer, const generalName_t *gn)
 {
     fetch_req_t *req;
 
-    lock_fetch_list("add_fetch_request");
-    req = fetch_reqs;
+    lock_crl_fetch_list("add_crl_fetch_request");
+    req = crl_fetch_reqs;
 
     while (req != NULL)
     {
@@ -654,13 +869,13 @@ add_fetch_request(chunk_t issuer, const generalName_t *gn)
 	{
 	    /* there is already a fetch request */
 	    DBG(DBG_CONTROL,
-		DBG_log("fetch request already exists")
+		DBG_log("crl fetch request already exists")
 	    )
 
 	    /* there might be new distribution points */
 	    add_distribution_points(gn, &req->distributionPoints);
 
-	    unlock_fetch_list("add_fetch_request");
+	    unlock_crl_fetch_list("add_crl_fetch_request");
 	    return;
 	}
 	req = req->next;
@@ -679,13 +894,28 @@ add_fetch_request(chunk_t issuer, const generalName_t *gn)
     add_distribution_points(gn, &req->distributionPoints);
 
     /* insert new fetch request at the head of the queue */
-    req->next = fetch_reqs;
-    fetch_reqs = req;
+    req->next = crl_fetch_reqs;
+    crl_fetch_reqs = req;
 
     DBG(DBG_CONTROL,
-	DBG_log("fetch request added")
+	DBG_log("crl fetch request added")
     )
-    unlock_fetch_list("add_fetch_request");
+    unlock_crl_fetch_list("add_crl_fetch_request");
+}
+
+/*
+ * add an ocsp fetch request to the chained list
+ */
+void
+add_ocsp_fetch_request(ocsp_location_t *location, chunk_t serialNumber)
+{
+    ocsp_certinfo_t certinfo;
+    
+    certinfo.serialNumber = serialNumber;
+
+    lock_ocsp_fetch_list("add_ocsp_fetch_request");
+    add_certinfo(location, &certinfo, &ocsp_fetch_reqs, TRUE);
+    unlock_ocsp_fetch_list("add_ocsp_fetch_request");
 }
 
 /*
@@ -709,30 +939,41 @@ list_distribution_points(const generalName_t *gn)
  *  list all fetch requests in the chained list
  */
 void
-list_fetch_requests(bool utc)
+list_crl_fetch_requests(bool utc)
 {
     fetch_req_t *req;
 
-    lock_fetch_list("list_fetch_requests");
-    req = fetch_reqs;
+    lock_crl_fetch_list("list_crl_fetch_requests");
+    req = crl_fetch_reqs;
 
     if (req != NULL)
     {
 	whack_log(RC_COMMENT, " ");
-	whack_log(RC_COMMENT, "List of fetch requests:");
+	whack_log(RC_COMMENT, "List of CRL fetch requests:");
 	whack_log(RC_COMMENT, " ");
     }
 
     while (req != NULL)
     {
-	u_char buf[BUF_LEN];
+	u_char buf[BUF_LEN];	
+	char tbuf2[TIMETOA_BUF];
 
 	whack_log(RC_COMMENT, "%s, trials: %d"
-	    , timetoa(&req->installed, utc), req->trials);
+		  , timetoa(&req->installed, utc, tbuf2, sizeof(tbuf2))
+		  , req->trials);
 	dntoa(buf, BUF_LEN, req->issuer);
 	whack_log(RC_COMMENT, "       issuer:  '%s'", buf);
 	list_distribution_points(req->distributionPoints);
 	req = req->next;
     }
-    unlock_fetch_list("list_fetch_requests");
+    unlock_crl_fetch_list("list_crl_fetch_requests");
+}
+
+void
+list_ocsp_fetch_requests(bool utc)
+{
+    lock_ocsp_fetch_list("list_ocsp_fetch_requests");
+    list_ocsp_locations(ocsp_fetch_reqs, TRUE, utc, FALSE);
+    unlock_ocsp_fetch_list("list_ocsp_fetch_requests");
+
 }
