@@ -14,7 +14,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: kernel_noklips.c,v 1.8 2004/06/01 14:43:20 ken Exp $
+ * RCSID $Id: kernel_noklips.c,v 1.10 2005/07/08 17:55:28 mcr Exp $
  */
 
 #include <errno.h>
@@ -125,4 +125,6 @@ const struct kernel_ops noklips_kernel_ops = {
 	get_spi: NULL,
         inbound_eroute: FALSE,
 	policy_lifetime: FALSE,
+	docommand: NULL,
+	opname: "noklips",
 };
