@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: keys.c,v 1.97 2004/10/21 19:08:29 mcr Exp $
+ * RCSID $Id: keys.c,v 1.102.2.1 2005/08/19 17:52:42 ken Exp $
  */
 
 #include <stddef.h>
@@ -50,6 +50,7 @@
 #include "state.h"
 #include "lex.h"
 #include "keys.h"
+#include "secrets.h"
 #include "adns.h"	/* needs <resolv.h> */
 #include "dnskey.h"	/* needs keys.h and adns.h */
 #include "log.h"
@@ -403,7 +404,7 @@ get_secret(const struct connection *c, enum PrivateKeyKind kind, bool asym)
 	    DBG(DBG_CONTROL,
 		DBG_log("searching for certificate %s:%s vs %s:%s"
 			, enum_name(&ppk_names, s->kind)
-			, s->u.RSA_private_key.pub.keyid
+			, (s->kind==PPK_RSA ? s->u.RSA_private_key.pub.keyid : "N/A")
 			, enum_name(&ppk_names, kind)
 			, my_public_key->u.rsa.keyid)
 	      );
@@ -418,8 +419,8 @@ get_secret(const struct connection *c, enum PrivateKeyKind kind, bool asym)
 	free_public_key(my_public_key);
 	return best;
     }
-
-    if (his_id_was_instantiated(c) && !(c->policy&AGGRESSIVE))
+#if defined(AGGRESSIVE)
+    if (his_id_was_instantiated(c) && !(c->policy & POLICY_AGGRESSIVE))
     {
 	DBG(DBG_CONTROL,
 	    DBG_log("instantiating him to 0.0.0.0"));
@@ -431,6 +432,7 @@ get_secret(const struct connection *c, enum PrivateKeyKind kind, bool asym)
 	his_id = &rw_id;
 	idtoa(his_id, idhim2, IDTOA_BUF);
     }
+#endif
 #ifdef NAT_TRAVERSAL
     else if ((nat_traversal_enabled)
 	     && (c->policy & POLICY_PSK)
@@ -628,6 +630,14 @@ get_RSA_private_key(const struct connection *c)
 {
     const struct secret *s = get_secret(c, PPK_RSA, TRUE);
 
+#ifdef DEBUG
+    DBG(DBG_PRIVATE,
+	if (s == NULL)
+	    DBG_log("no RSA key Found");
+	else
+	    DBG_log("rsa key %s found", s->u.RSA_private_key.pub.keyid);
+	);
+#endif
     return s == NULL? NULL : &s->u.RSA_private_key;
 }
 
@@ -1198,6 +1208,7 @@ process_secrets_file(const char *file_pat, int whackfd)
     char **fnp;
     glob_t globbuf;
 
+    memset(&globbuf, 0, sizeof(glob_t));
     pos.depth = flp == NULL? 0 : flp->depth + 1;
 
     if (pos.depth > 10)
@@ -1232,7 +1243,7 @@ process_secrets_file(const char *file_pat, int whackfd)
     }
 
     /* for each file... */
-    for (fnp = globbuf.gl_pathv; *fnp != NULL; fnp++)
+    for (fnp = globbuf.gl_pathv; fnp!=NULL && *fnp != NULL; fnp++)
     {
 	if (lexopen(&pos, *fnp, FALSE))
 	{
