@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: pluto_constants.c,v 1.11 2004/11/12 04:25:47 mcr Exp $
+ * RCSID $Id: pluto_constants.c,v 1.15.2.3 2005/08/19 17:58:09 ken Exp $
  */
 
 /*
@@ -52,14 +52,24 @@ const char compile_time_interop_options[] = ""
 #endif
     ;
 
+static const char *const kern_interface_name[] = {
+  "none",
+  "auto-pick",
+  "klips",
+  "netkey"
+};
+enum_names kern_interface_names = 
+  { NO_KERNEL, USE_NETKEY, kern_interface_name, NULL };
+
 /* DPD actions */
 static const char *const dpd_action_name[] = {
   "action:clear",
   "action:hold",
+  "action:restart",
 };
 
 enum_names dpd_action_names =
-    { EVENT_NULL, DPD_ACTION_HOLD, dpd_action_name, NULL };
+    { EVENT_NULL, DPD_ACTION_RESTART, dpd_action_name, NULL };
 
 /* Timer events */
 static const char *const timer_event_name[] = {
@@ -75,11 +85,12 @@ static const char *const timer_event_name[] = {
 	"EVENT_DPD",
 	"EVENT_DPD_TIMEOUT",
 	"EVENT_LOG_DAILY",
-	"EVENT_CRYPTO_FAILED"
+	"EVENT_CRYPTO_FAILED",
+	"EVENT_PENDING_PHASE2"
     };
 
 enum_names timer_event_names =
-    { EVENT_NULL, EVENT_CRYPTO_FAILED, timer_event_name, NULL };
+    { EVENT_NULL, EVENT_PENDING_PHASE2, timer_event_name, NULL };
 
 /* State of exchanges */
 static const char *const state_name[] = {
@@ -176,6 +187,8 @@ static const char *const pluto_cryptoop_strings[] = {
   "x509cert_fetch",     /* X.509 fetch operation */
   "x509crl_fetch",      /* X.509 crl fetch operation */
   "build_nonce",        /* just fetch a new nonce */
+  "compute dh+iv",      /* perform (g^x)(g^y) and calculate skeyids */
+  "compute dh(p2)",     /* perform (g^x)(g^y) */
 };
 
 enum_names pluto_cryptoop_names =
@@ -212,8 +225,9 @@ static const char *const routing_story_strings[] = {
 enum_names routing_story =
     { RT_UNROUTED, RT_ROUTED_TUNNEL, routing_story_strings, NULL};
 
-static const char *const stfstatus_names[6] = {
+static const char *const stfstatus_names[] = {
 	"STF_IGNORE",
+	"STF_INLINE",
 	"STF_SUSPEND",
 	"STF_OK",
 	"STF_INTERNAL_ERROR",
