@@ -14,7 +14,7 @@
  *
  * This code was developed with the support of IXIA communications.
  *
- * RCSID $Id: pluto_crypt.c,v 1.12 2004/11/30 02:27:50 mcr Exp $
+ * RCSID $Id: pluto_crypt.c,v 1.19 2005/07/13 02:14:08 mcr Exp $
  */
 
 #include <stdlib.h>
@@ -61,7 +61,7 @@ static struct pluto_crypto_req_cont *backlogqueue;
 static int                           backlogqueue_len;
 
 static void init_crypto_helper(struct pluto_crypto_worker *w, int n);
-static void cleanup_crypto_helper(struct pluto_crypto_worker *w);
+static void cleanup_crypto_helper(struct pluto_crypto_worker *w, int status);
 static void handle_helper_comm(struct pluto_crypto_worker *w);
 extern void free_preshared_secrets(void);
 
@@ -94,6 +94,14 @@ void pluto_do_crypto_op(struct pluto_crypto_req *r)
 	calc_nonce(r);
 	break;
 
+    case pcr_compute_dh_iv:
+	calc_dh_iv(r);
+	break;
+
+    case pcr_compute_dh:
+	calc_dh(r);
+	break;
+
     case pcr_rsa_sign:
     case pcr_rsa_check:
     case pcr_x509cert_fetch:
@@ -102,22 +110,6 @@ void pluto_do_crypto_op(struct pluto_crypto_req *r)
     }
 }
 
-void pluto_crypto_allocchunk(wire_chunk_t *space
-			     , wire_chunk_t *new
-			     , size_t howbig)
-{
-    /*
-     * passert for now, since we should be able to figure out what
-     * the maximum is.
-     */
-    passert(space->start + howbig < space->len);
-
-    new->start = space->start;
-    new->len   = howbig;
-    
-    space->start += howbig;
-}
-
 static void catchhup(int signo UNUSED)
 {
     /* socket closed die */
@@ -167,6 +159,7 @@ void pluto_crypto_helper(int fd, int helpernum)
     DBG(DBG_CONTROL, DBG_log("helper %d waiting on fd: %d"
 			      , helpernum, fd));
 
+    memset(reqbuf, 0, sizeof(reqbuf));
     while(read(fd, reqbuf, sizeof(r->pcr_len)) == sizeof(r->pcr_len)) {
 	int restlen;
 	int actlen;
@@ -193,6 +186,7 @@ void pluto_crypto_helper(int fd, int helpernum)
 	    loglog(RC_LOG_SERIOUS, "failed to write answer: %d", actlen);
 	    exit(2);
 	}
+	memset(reqbuf, 0, sizeof(reqbuf));
     }
 
     /* probably normal EOF */
@@ -211,7 +205,8 @@ void pluto_crypto_helper(int fd, int helpernum)
  *
  */
 err_t send_crypto_helper_request(struct pluto_crypto_req *r
-				 , struct pluto_crypto_req_cont *cn)
+				 , struct pluto_crypto_req_cont *cn
+				 , bool *toomuch)
 {
     struct pluto_crypto_worker *w;
     int cnt;
@@ -224,6 +219,9 @@ err_t send_crypto_helper_request(struct pluto_crypto_req *r
 	/* call the continuation */
 	(*cn->pcrc_func)(cn, r, NULL);
 
+	/* indicate that we did everything ourselves */
+	*toomuch = TRUE;
+
 	pfree(cn);
 	pfree(r);
 	return NULL;
@@ -257,7 +255,7 @@ err_t send_crypto_helper_request(struct pluto_crypto_req *r
 	/* see if there is something to clean up after */
 	if(w->pcw_dead      == TRUE
 	   && w->pcw_reaped == TRUE) {
-	    cleanup_crypto_helper(w);
+	    cleanup_crypto_helper(w, 0);
 	}
 	DBG(DBG_CONTROL
 	    , DBG_log("%d: w->pcw_dead: %d w->pcw_work: %d cnt: %d",
@@ -275,7 +273,7 @@ err_t send_crypto_helper_request(struct pluto_crypto_req *r
 	    /* see if there is something to clean up after */
 	    if(w->pcw_dead      == TRUE
 	       && w->pcw_reaped == TRUE) {
-		cleanup_crypto_helper(w);
+		cleanup_crypto_helper(w, 0);
 	    }
 	    DBG(DBG_CONTROL
 		, DBG_log("crit %d: w->pcw_dead: %d w->pcw_work: %d cnt: %d",
@@ -292,7 +290,7 @@ err_t send_crypto_helper_request(struct pluto_crypto_req *r
 	DBG(DBG_CONTROL
 	    , DBG_log("critical demand crypto operation queued as item %d"
 		      , backlogqueue_len));
-
+	*toomuch = FALSE;
 	return NULL;
     }
 
@@ -301,6 +299,7 @@ err_t send_crypto_helper_request(struct pluto_crypto_req *r
 	DBG(DBG_CONTROL
 	    , DBG_log("failed to find any available worker"));
 
+	*toomuch = TRUE;
 	return "failed to find any available worker";
     }
 
@@ -310,6 +309,7 @@ err_t send_crypto_helper_request(struct pluto_crypto_req *r
 	if(w->pcw_pid == -1) {
 	    DBG(DBG_CONTROL
 		, DBG_log("found only a dead helper, and failed to restart it"));
+	    *toomuch = TRUE;
 	    return "failed to start a new helper";
 	}
     }
@@ -335,6 +335,7 @@ err_t send_crypto_helper_request(struct pluto_crypto_req *r
     } 
 
     w->pcw_work++;
+    *toomuch = FALSE;
     return NULL;
 }
 
@@ -399,7 +400,7 @@ static void crypto_send_backlog(struct pluto_crypto_worker *w)
     }
 }
 
-bool pluto_crypt_handle_dead_child(int pid, int status UNUSED)
+bool pluto_crypt_handle_dead_child(int pid, int status)
 {
     int cnt;
     struct pluto_crypto_worker *w = pc_workers;
@@ -409,15 +410,54 @@ bool pluto_crypt_handle_dead_child(int pid, int status UNUSED)
 	    w->pcw_reaped = TRUE;
 	    
 	    if(w->pcw_dead == TRUE) {
-		cleanup_crypto_helper(w);
+		cleanup_crypto_helper(w, status);
 	    }
 	    return TRUE;
 	}
     }
     return FALSE;
 }    
-	
 
+/*
+ * look for any states attaches to continuations
+ */
+void delete_cryptographic_continuation(struct state *st)
+{
+    int i;
+
+    for(i=0; i<pc_workers_cnt; i++) {
+	struct pluto_crypto_worker *w = &pc_workers[i];
+	struct pluto_crypto_req_cont *cn, **cnp;
+
+	cn = w->pcw_cont;
+	cnp = &w->pcw_cont;
+	while(cn && st->st_serialno != cn->pcrc_serialno) {
+	    cnp = &cn->pcrc_next;
+	    cn = cn->pcrc_next;
+	}
+	
+	if(cn == NULL) {
+	    DBG(DBG_CRYPT, DBG_log("no suspended cryptographic state for %lu\n"
+				   , st->st_serialno));
+	    return;
+	}
+
+	/* unlink it, and free it */
+	*cnp = cn->pcrc_next;
+	cn->pcrc_next = NULL;
+ 
+	if(cn->pcrc_free) {
+	    /*
+	     * use special free function which can deal with other
+	     * saved structures.
+	     */
+	    (*cn->pcrc_free)(cn, cn->pcrc_pcr, "state removed");
+	} else {
+	    pfree(cn);
+	}
+    }
+}
+	
 /*
  * this function is called when there is a helper pipe that is ready.
  * we read the request from the pipe, and find the associated continuation,
@@ -456,7 +496,7 @@ void handle_helper_comm(struct pluto_crypto_worker *w)
 	 */
 	w->pcw_dead = TRUE;
 	if(w->pcw_reaped) {
-	    cleanup_crypto_helper(w);
+	    cleanup_crypto_helper(w, 0);
 	}
 	return;
     }
@@ -648,15 +688,16 @@ static void init_crypto_helper(struct pluto_crypto_worker *w, int n)
 /*
  * clean up after a crypto helper
  */
-static void cleanup_crypto_helper(struct pluto_crypto_worker *w)
+static void cleanup_crypto_helper(struct pluto_crypto_worker *w
+				  , int status)
 {
-    w->pcw_pid = -1;
     if(w->pcw_pipe) {
-	loglog(RC_LOG_SERIOUS, "closing helper(%u) pid=%d fd=%d"
-	       , w->pcw_helpernum, w->pcw_pid, w->pcw_pipe);
+	loglog(RC_LOG_SERIOUS, "closing helper(%u) pid=%d fd=%d exit=%d"
+	       , w->pcw_helpernum, w->pcw_pid, w->pcw_pipe, status);
 	close(w->pcw_pipe);
     }
 
+    w->pcw_pid = -1;
     w->pcw_reaped = FALSE;
     w->pcw_dead   = FALSE;   /* marking is not dead lets it live again */
 }
