@@ -13,7 +13,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: plutomain.c,v 1.96 2004/10/18 00:07:39 mcr Exp $
+ * RCSID $Id: plutomain.c,v 1.102.2.4 2005/08/12 01:15:00 ken Exp $
  */
 
 #include <stdio.h>
@@ -56,6 +56,7 @@
 #include "kernel.h"	/* needs connections.h */
 #include "log.h"
 #include "keys.h"
+#include "secrets.h"
 #include "adns.h"	/* needs <resolv.h> */
 #include "dnskey.h"	/* needs keys.h and adns.h */
 #include "rnd.h"
@@ -83,6 +84,7 @@
 #endif
 
 const char *ipsec_dir = IPSECDIR;
+const char *ctlbase = "/var/run/pluto";
 
 openswan_passert_fail_t openswan_passert_fail = passert_fail;
 
@@ -103,12 +105,15 @@ usage(const char *mess)
 	    " \\\n\t"
 	    "[--nofork]"
 	    " [--stderrlog]"
-	    " [--noklips]"
+	    " [--use-nostack]"         /* old --no_klips */
 	    " [--nocrsend]"
 	    " [--strictcrlpolicy]"
 	    " [--crlcheckinterval]"
 	    " [--ocspuri]"
 	    " [--uniqueids]"
+	    " [--use-auto]"
+	    " [--use-klips]"
+	    " [--use-netkey]"
 	    " \\\n\t"
 	    "[--interface <ifname>]"
 	    " [--ikeport <port-number>]"
@@ -140,7 +145,7 @@ usage(const char *mess)
 	    " [ --debug-pfkey]"
 #endif
 #ifdef NAT_TRAVERSAL
-	    " [ --debug-nat_t]"
+	    " [ --debug-nat-t]"
 	    " \\\n\t"
 	    "[--nat_traversal] [--keep_alive <delay_sec>]"
 	    " \\\n\t"
@@ -171,8 +176,18 @@ static bool pluto_lock_created = FALSE;
 static int
 create_lock(void)
 {
-    int fd = open(pluto_lock, O_WRONLY | O_CREAT | O_EXCL | O_TRUNC
-	, S_IRUSR | S_IRGRP | S_IROTH);
+    int fd;
+
+    if(mkdir(ctlbase, 0755) != 0) {
+	if(errno != EEXIST) {
+	    fprintf(stderr, "pluto: unable to create lock dir: \"%s\": %s\n"
+		    , ctlbase, strerror(errno));
+	    exit_pluto(10);
+	}
+    }
+	    
+    fd = open(pluto_lock, O_WRONLY | O_CREAT | O_EXCL | O_TRUNC
+	      , S_IRUSR | S_IRGRP | S_IROTH);
 
     if (fd < 0)
     {
@@ -233,6 +248,9 @@ bool strict_crl_policy = FALSE;
 /** by default pluto does not check crls dynamically */
 long crl_check_interval = 0;
 
+/* whether or not to use klips */
+enum kernel_interface kern_interface = AUTO_PICK;
+
 char **global_argv;
 int    global_argc;
 
@@ -277,12 +295,18 @@ main(int argc, char **argv)
 	    { "nofork", no_argument, NULL, 'd' },
 	    { "stderrlog", no_argument, NULL, 'e' },
 	    { "noklips", no_argument, NULL, 'n' },
+	    { "use-nostack",  no_argument, NULL, 'n' },
 	    { "nocrsend", no_argument, NULL, 'c' },
 	    { "strictcrlpolicy", no_argument, NULL, 'r' },
 	    { "crlcheckinterval", required_argument, NULL, 'x'},
 	    { "ocsprequestcert", required_argument, NULL, 'q'},
 	    { "ocspuri", required_argument, NULL, 'o'},
 	    { "uniqueids", no_argument, NULL, 'u' },
+	    { "useklips",  no_argument, NULL, 'k' },
+	    { "use-klips",  no_argument, NULL, 'k' },
+	    { "use-auto",  no_argument, NULL, 'G' },
+	    { "usenetkey", no_argument, NULL, 'K' },
+	    { "use-netkey", no_argument, NULL, 'K' },
 	    { "interface", required_argument, NULL, 'i' },
 	    { "ikeport", required_argument, NULL, 'p' },
 	    { "ctlbase", required_argument, NULL, 'b' },
@@ -305,6 +329,8 @@ main(int argc, char **argv)
 	    { "force_keepalive", no_argument, NULL, '3' },
 	    { "disable_port_floating", no_argument, NULL, '4' },
 	    { "debug-nat_t", no_argument, NULL, '5' },
+	    { "debug-nattraversal", no_argument, NULL, '5' },
+	    { "debug-nat-t", no_argument, NULL, '5' },
 #endif
 #ifdef VIRTUAL_IP
 	    { "virtual_private", required_argument, NULL, '6' },
@@ -332,6 +358,7 @@ main(int argc, char **argv)
 	    { "impair-delay-adns-txt-answer", no_argument, NULL, IMPAIR_DELAY_ADNS_TXT_ANSWER + DBG_OFFSET },
 	    { "impair-bust-mi2", no_argument, NULL, IMPAIR_BUST_MI2 + DBG_OFFSET },
 	    { "impair-bust-mr2", no_argument, NULL, IMPAIR_BUST_MR2 + DBG_OFFSET },
+	    { "impair-jacob-two-two", no_argument, NULL, IMPAIR_JACOB_TWO_TWO + DBG_OFFSET },
 #endif
 	    { 0,0,0,0 }
 	    };
@@ -403,8 +430,20 @@ main(int argc, char **argv)
 	    log_to_stderr_desired = TRUE;
 	    continue;
 
-	case 'n':	/* --noklips */
-	    no_klips = TRUE;
+	case 'G':       /* --use-auto */
+	    kern_interface = AUTO_PICK;
+	    continue;
+
+	case 'k':       /* --use-klips */
+	    kern_interface = USE_KLIPS;
+	    continue;
+
+	case 'K':       /* --use-netkey */
+	    kern_interface = USE_NETKEY;
+	    continue;
+
+	case 'n':	/* --use-nostack */
+	    kern_interface = NO_KERNEL;
 	    continue;
 
 	case 'c':	/* --nocrsend */
@@ -466,14 +505,15 @@ main(int argc, char **argv)
 	    continue;
 
 	case 'b':	/* --ctlbase <path> */
+	    ctlbase = optarg;
 	    if (snprintf(ctl_addr.sun_path, sizeof(ctl_addr.sun_path)
-	    , "%s%s", optarg, CTL_SUFFIX) == -1)
+			 , "%s%s", ctlbase, CTL_SUFFIX) == -1)
 		usage("<path>" CTL_SUFFIX " too long for sun_path");
 	    if (snprintf(info_addr.sun_path, sizeof(info_addr.sun_path)
-	    , "%s%s", optarg, INFO_SUFFIX) == -1)
+			 , "%s%s", ctlbase, INFO_SUFFIX) == -1)
 		usage("<path>" INFO_SUFFIX " too long for sun_path");
 	    if (snprintf(pluto_lock, sizeof(pluto_lock)
-	    , "%s%s", optarg, LOCK_SUFFIX) == -1)
+			 , "%s%s", ctlbase, LOCK_SUFFIX) == -1)
 		usage("<path>" LOCK_SUFFIX " must fit");
 	    continue;
 
@@ -674,11 +714,22 @@ main(int argc, char **argv)
     {
 #ifdef PLUTO_SENDS_VENDORID
         const char *v = init_pluto_vendorid();
+	const char *vc = ipsec_version_code();
 
         openswan_log("Starting Pluto (Openswan Version %s%s; Vendor ID %s)"
-            , ipsec_version_code()
+            , vc
             , compile_time_interop_options
             , v);
+	if(vc[0]=='c' && vc[1]=='v' && vc[2]=='s') {
+	    /*
+	     * when people build RPMs from CVS, make sure they get blamed
+	     * appropriately, and that we get some way to identify who
+	     * did it, and when they did it. Use string concat, so that
+	     * strings the binary can or classic SCCS "what", will find
+	     * stuff too.
+	     */
+	    openswan_log("@(#) built on "__DATE__":"__TIME__":"BUILDER);
+	}
 #else
         openswan_log("Starting Pluto (Openswan Version %s%s)"
             , ipsec_version_code()
@@ -702,6 +753,7 @@ main(int argc, char **argv)
     init_rnd_pool();
     init_secret();
     init_states();
+    init_connections();
     init_crypto();
     init_crypto_helpers(nhelpers);
     init_demux();
