@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: spdb.c,v 1.117 2004/11/30 02:28:28 mcr Exp $
+ * RCSID $Id: spdb.c,v 1.120 2005/07/05 22:07:06 mcr Exp $
  */
 
 #include <stdio.h>
@@ -24,6 +24,7 @@
 
 #include <openswan.h>
 #include <openswan/ipsec_policy.h>
+#include "pfkeyv2.h"
 
 #include "constants.h"
 #include "oswlog.h"
@@ -763,6 +764,8 @@ void
 free_sa(struct db_sa *f)
 {
     int i;
+    if(f == NULL) return;
+
     for(i=0; i<f->prop_conj_cnt; i++) {
 	free_sa_prop_conj(&f->prop_conjs[i]);
     }
@@ -927,62 +930,6 @@ sa_merge_proposals(struct db_sa *a, struct db_sa *b)
     return n;
 }
 
-#ifdef PRINT_SA_DEBUG
-void
-print_sa_attr(struct db_attr *at)
-{
-    if(at->type == 0) {
-	return;
-    }
-    
-    printf("        type: %u val: %d\n", at->type, at->val);
-}
-
-void
-print_sa_trans(struct db_trans *tr)
-{
-    int i;
-    printf("      transform: %d cnt: %d\n",
-	   tr->transid, tr->attr_cnt);
-    for(i=0; i<tr->attr_cnt; i++) {
-	print_sa_attr(&tr->attrs[i]);
-    }
-}
-
-void
-print_sa_prop(struct db_prop *dp)
-{
-    int i;
-    printf("    protoid: %d cnt: %d\n",
-	   dp->protoid, dp->trans_cnt);
-    for(i=0; i<dp->trans_cnt; i++) {
-	print_sa_trans(&dp->trans[i]);
-    }
-}
-
-void
-print_sa_prop_conj(struct db_prop_conj *pc)
-{
-    int i;
-    printf("  conjunctions cnt: %d\n",
-	   pc->prop_cnt);
-    for(i=0; i<pc->prop_cnt; i++) {
-	print_sa_prop(&pc->props[i]);
-    }
-}
-
-void
-sa_print(struct db_sa *f)
-{
-    int i;
-    printf("sa disjunct cnt: %d\n",
-	   f->prop_conj_cnt);
-    for(i=0; i<f->prop_conj_cnt; i++) {
-	print_sa_prop_conj(&f->prop_conjs[i]);
-    }
-}
-#endif
-
 /*
  * Local Variables:
  * c-style: pluto
