@@ -13,7 +13,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: whack.c,v 1.139 2004/12/16 01:21:59 mcr Exp $
+ * RCSID $Id: whack.c,v 1.144.4.3 2005/07/26 02:11:23 ken Exp $
  */
 
 #include <stdio.h>
@@ -116,7 +116,7 @@ help(void)
 	    " [--aggrmode]"
             " [--dpddelay <seconds> --dpdtimeout <seconds>]"
             " \\\n   "
-            " [--dpdaction (clear|hold)]"
+            " [--dpdaction (clear|hold|restart)]"
 	    " [--forceencaps]"
 
 
@@ -230,7 +230,7 @@ help(void)
 	"shutdown: whack"
 	    " --shutdown"
 	    "\n\n"
-	"FreeS/WAN %s\n"
+	"Openswan %s\n"
 	, ipsec_version_code());
 }
 
@@ -466,9 +466,12 @@ enum option_enums {
     DBGOPT_IMPAIR_DELAY_ADNS_KEY_ANSWER,	/* same order as IMPAIR_* */
     DBGOPT_IMPAIR_DELAY_ADNS_TXT_ANSWER,	/* same order as IMPAIR_* */
     DBGOPT_IMPAIR_BUST_MI2,	/* same order as IMPAIR_* */
-    DBGOPT_IMPAIR_BUST_MR2	/* same order as IMPAIR_* */
+    DBGOPT_IMPAIR_BUST_MR2,	/* same order as IMPAIR_* */
+    DBGOPT_IMPAIR_SA_CREATION,  /* make all SA creation fail */
+    DBGOPT_IMPAIR_DIE_ONINFO,   /* cause state to be deleted upon receipt of information payload */
+    DBGOPT_IMPAIR_JACOB_TWO_TWO, /* cause pluto to send all messages twice */
 
-#   define DBGOPT_LAST DBGOPT_IMPAIR_BUST_MR2
+#   define DBGOPT_LAST DBGOPT_IMPAIR_DIE_ONINFO
 #endif
 
 };
@@ -643,6 +646,9 @@ static const struct option long_opts[] = {
     { "debug-controlmore", no_argument, NULL, DBGOPT_CONTROLMORE + OO },
     { "debug-pfkey",   no_argument, NULL, DBGOPT_PFKEY + OO },
     { "debug-nattraversal", no_argument, NULL, DBGOPT_NATT + OO },
+    { "debug-natt",    no_argument, NULL, DBGOPT_NATT + OO },
+    { "debug-nat_t",   no_argument, NULL, DBGOPT_NATT + OO },
+    { "debug-nat-t",   no_argument, NULL, DBGOPT_NATT + OO },
     { "debug-x509",    no_argument, NULL, DBGOPT_X509 + OO },
     { "debug-dpd",     no_argument, NULL, DBGOPT_DPD + OO },
     { "debug-private", no_argument, NULL, DBGOPT_PRIVATE + OO },
@@ -651,6 +657,9 @@ static const struct option long_opts[] = {
     { "impair-delay-adns-txt-answer", no_argument, NULL, DBGOPT_IMPAIR_DELAY_ADNS_TXT_ANSWER + OO },
     { "impair-bust-mi2", no_argument, NULL, DBGOPT_IMPAIR_BUST_MI2 + OO },
     { "impair-bust-mr2", no_argument, NULL, DBGOPT_IMPAIR_BUST_MR2 + OO },
+    { "impair-sa-fail",    no_argument, NULL, DBGOPT_IMPAIR_SA_CREATION + OO },
+    { "impair-die-oninfo", no_argument, NULL, DBGOPT_IMPAIR_DIE_ONINFO  + OO },
+    { "impair-jacob-two-two", no_argument, NULL, DBGOPT_IMPAIR_JACOB_TWO_TWO + OO },
 #endif
 #   undef OO
     { 0,0,0,0 }
@@ -852,14 +861,14 @@ main(int argc, char **argv)
         lst_seen = LEMPTY,
         cd_seen = LEMPTY,
         end_seen = LEMPTY,
-        end_seen_before_to;
+        end_seen_before_to = LEMPTY;
     const char
 	*af_used_by = NULL,
 	*tunnel_af_used_by = NULL;
 
     char xauthname[128];
     char xauthpass[128];
-    int xauthnamelen, xauthpasslen;
+    int xauthnamelen = 0, xauthpasslen = 0;
     bool gotxauthname = FALSE, gotxauthpass = FALSE;
 
     /* check division of numbering space */
@@ -901,7 +910,7 @@ main(int argc, char **argv)
     for (;;)
     {
 	int long_index;
-	unsigned long opt_whole;	/* numeric argument for some flags */
+	unsigned long opt_whole=0;	/* numeric argument for some flags */
 
 	/* Note: we don't like the way short options get parsed
 	 * by getopt_long, so we simply pass an empty string as
@@ -1464,6 +1473,9 @@ main(int argc, char **argv)
             if( strcmp(optarg, "hold") == 0) {
                     msg.dpd_action = DPD_ACTION_HOLD;
             }
+            if( strcmp(optarg, "restart") == 0) {
+                    msg.dpd_action = DPD_ACTION_RESTART;
+            }
             continue;
 
 	case CD_IKE:	/* --ike <ike_alg1,ike_alg2,...> */
@@ -1569,6 +1581,9 @@ main(int argc, char **argv)
 	case DBGOPT_IMPAIR_DELAY_ADNS_TXT_ANSWER:	/* --impair-delay-adns-txt-answer */
 	case DBGOPT_IMPAIR_BUST_MI2:	/* --impair_bust_mi2 */
 	case DBGOPT_IMPAIR_BUST_MR2:	/* --impair_bust_mr2 */
+	case DBGOPT_IMPAIR_SA_CREATION:	/* --impair-sa-creation */
+	case DBGOPT_IMPAIR_DIE_ONINFO:	/* --impair-die-oninfo */
+	case DBGOPT_IMPAIR_JACOB_TWO_TWO: /* --impair-jacob-two-two */
 	    msg.debugging |= LELEM(c-DBGOPT_RAW);
 	    continue;
 #endif
@@ -1683,11 +1698,13 @@ main(int argc, char **argv)
     }
 
     if (!(msg.whack_connection || msg.whack_key || msg.whack_myid
-    || msg.whack_delete || msg.whack_deletestate
-    || msg.whack_initiate || msg.whack_oppo_initiate || msg.whack_terminate
-    || msg.whack_route || msg.whack_unroute || msg.whack_listen
-    || msg.whack_unlisten || msg.whack_list || msg.whack_purgeocsp || msg.whack_reread
-    || msg.whack_status || msg.whack_options || msg.whack_shutdown))
+	  || msg.whack_delete || msg.whack_deletestate
+	  || msg.whack_initiate || msg.whack_oppo_initiate
+	  || msg.whack_terminate
+	  || msg.whack_route || msg.whack_unroute || msg.whack_listen
+	  || msg.whack_unlisten || msg.whack_list || msg.whack_purgeocsp
+	  || msg.whack_reread || msg.whack_crash
+	  || msg.whack_status || msg.whack_options || msg.whack_shutdown))
     {
 	diag("no action specified; try --help for hints");
     }
@@ -1716,8 +1733,8 @@ main(int argc, char **argv)
             diag("dpddelay specified, but dpdtimeout is zero, both should be specified");
     if(!msg.dpd_delay && msg.dpd_timeout)
             diag("dpdtimeout specified, but dpddelay is zero, both should be specified");
-    if(msg.dpd_action != DPD_ACTION_CLEAR && msg.dpd_action != DPD_ACTION_HOLD) {
-            diag("dpdaction can only be \"clear\" or \"hold\", defaulting to \"hold\"");
+    if(msg.dpd_action != DPD_ACTION_CLEAR && msg.dpd_action != DPD_ACTION_HOLD && msg.dpd_action != DPD_ACTION_RESTART) {
+            diag("dpdaction can only be \"clear\", \"hold\" or \"restart\", defaulting to \"hold\"");
             msg.dpd_action = DPD_ACTION_HOLD;
     }
 
@@ -1863,6 +1880,7 @@ main(int argc, char **argv)
 
 		    le++;	/* include NL in line */
 		    write(1, ls, le - ls);
+		    fsync(1);
 
 		    /* figure out prefix number
 		     * and how it should affect our exit status
