@@ -14,7 +14,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: xauth.c,v 1.35 2004/11/30 15:30:24 mcr Exp $
+ * RCSID $Id: xauth.c,v 1.41.4.3 2005/07/26 02:11:23 ken Exp $
  *
  * This code originally written by Colubris Networks, Inc.
  * Extraction of patch and porting to 1.99 codebases by Xelerance Corporation
@@ -187,7 +187,7 @@ int get_internal_addresses(struct connection *con,struct internal_addr *ia)
 {
 #ifdef XAUTH_USEPAM
     int retval;
-    char str[48];
+    char str[IDTOA_BUF+sizeof("ID=")+2];
 #endif
 
 #ifdef NAT_TRAVERSAL /* only NAT-T code lets us do virtual ends */
@@ -222,7 +222,7 @@ int get_internal_addresses(struct connection *con,struct internal_addr *ia)
 					    memmove(buf, c1+3, strlen(c1) + 1 - 3);
 				    }
 			    }
-			    sprintf(str,"ID=%s", buf);
+			    snprintf(str, sizeof(str), "ID=%s", buf);
 			    pam_putenv(con->pamh,str);
 			    pam_open_session(con->pamh,0);
 		    }
@@ -252,13 +252,16 @@ int get_internal_addresses(struct connection *con,struct internal_addr *ia)
  * @return size_t Length of the HASH
  */
 size_t
-xauth_mode_cfg_hash(u_char *dest, const u_char *start, const u_char *roof, 
-const struct state *st)
+xauth_mode_cfg_hash(u_char *dest
+		    , const u_char *start
+		    , const u_char *roof
+		    , const struct state *st)
 {
     struct hmac_ctx ctx;
 
     hmac_init_chunk(&ctx, st->st_oakley.hasher, st->st_skeyid_a);
-    hmac_update(&ctx, (const u_char *) &st->st_msgid, sizeof(st->st_msgid));
+    hmac_update(&ctx, (const u_char *) &st->st_msgid_phase15
+		, sizeof(st->st_msgid_phase15));
     hmac_update(&ctx, start, roof-start);
     hmac_final(dest, &ctx);
 
@@ -481,7 +484,7 @@ stf_status modecfg_send_set(struct state *st)
 		hdr.isa_flags = ISAKMP_FLAG_ENCRYPTION;
 		memcpy(hdr.isa_icookie, st->st_icookie, COOKIE_SIZE);
 		memcpy(hdr.isa_rcookie, st->st_rcookie, COOKIE_SIZE);
-		hdr.isa_msgid = st->st_msgid;
+		hdr.isa_msgid = st->st_msgid_phase15;
 
 		if (!out_struct(&hdr, &isakmp_hdr_desc, &reply, &rbody))
 		{
@@ -503,7 +506,7 @@ stf_status modecfg_send_set(struct state *st)
 			, "ModeCfg set");
 
 	/* Transmit */
-	send_packet(st, "ModeCfg set");
+	send_packet(st, "ModeCfg set", TRUE);
 
 	/* RETRANSMIT if Main, SA_REPLACE if Aggressive */
 	if(st->st_event->ev_type != EVENT_RETRANSMIT
@@ -523,9 +526,9 @@ stf_status modecfg_send_set(struct state *st)
  */
 stf_status modecfg_start_set(struct state *st)
 {
-    if(st->st_msgid == 0) {
+    if(st->st_msgid_phase15 == 0) {
 	/* pick a new message id */
-	st->st_msgid = generate_msgid(st);
+	st->st_msgid_phase15 = generate_msgid(st);
     }
     st->hidden_variables.st_modecfg_vars_set = TRUE;
 
@@ -550,7 +553,7 @@ stf_status xauth_send_request(struct state *st)
 
 
     /* this is the beginning of a new exchange */
-    st->st_msgid = generate_msgid(st);
+    st->st_msgid_phase15 = generate_msgid(st);
     st->st_state = STATE_XAUTH_R0;
 
     /* HDR out */
@@ -564,7 +567,7 @@ stf_status xauth_send_request(struct state *st)
 	hdr.isa_flags = ISAKMP_FLAG_ENCRYPTION;
 	memcpy(hdr.isa_icookie, st->st_icookie, COOKIE_SIZE);
 	memcpy(hdr.isa_rcookie, st->st_rcookie, COOKIE_SIZE);
-	hdr.isa_msgid = st->st_msgid;
+	hdr.isa_msgid = st->st_msgid_phase15;
 
 	if (!out_struct(&hdr, &isakmp_hdr_desc, &reply, &rbody))
 	{
@@ -603,7 +606,7 @@ stf_status xauth_send_request(struct state *st)
     close_message(&rbody);
     close_output_pbs(&reply);
 
-    init_phase2_iv(st, &st->st_msgid);
+    init_phase2_iv(st, &st->st_msgid_phase15);
     encrypt_message(&rbody, st);
 
     clonetochunk(st->st_tpacket, reply.start, pbs_offset(&reply)
@@ -611,7 +614,7 @@ stf_status xauth_send_request(struct state *st)
 
     /* Transmit */
 
-    send_packet(st, "XAUTH: req");
+    send_packet(st, "XAUTH: req", TRUE);
 
     /* RETRANSMIT if Main, SA_REPLACE if Aggressive */
     if(st->st_event->ev_type != EVENT_RETRANSMIT)
@@ -640,7 +643,7 @@ stf_status modecfg_send_request(struct state *st)
     openswan_log("modecfg: Sending IP request (MODECFG_I1)");
 
     /* this is the beginning of a new exchange */
-    st->st_msgid = generate_msgid(st);
+    st->st_msgid_phase15 = generate_msgid(st);
     st->st_state = STATE_MODE_CFG_I1;
 
     /* HDR out */
@@ -654,7 +657,7 @@ stf_status modecfg_send_request(struct state *st)
 	hdr.isa_flags = ISAKMP_FLAG_ENCRYPTION;
 	memcpy(hdr.isa_icookie, st->st_icookie, COOKIE_SIZE);
 	memcpy(hdr.isa_rcookie, st->st_rcookie, COOKIE_SIZE);
-	hdr.isa_msgid = st->st_msgid;
+	hdr.isa_msgid = st->st_msgid_phase15;
 
 	if (!out_struct(&hdr, &isakmp_hdr_desc, &reply, &rbody))
 	{
@@ -693,7 +696,7 @@ stf_status modecfg_send_request(struct state *st)
     close_message(&rbody);
     close_output_pbs(&reply);
 
-    init_phase2_iv(st, &st->st_msgid);
+    init_phase2_iv(st, &st->st_msgid_phase15);
     encrypt_message(&rbody, st);
 
     clonetochunk(st->st_tpacket, reply.start, pbs_offset(&reply)
@@ -701,7 +704,7 @@ stf_status modecfg_send_request(struct state *st)
 
     /* Transmit */
 
-    send_packet(st, "modecfg: req");
+    send_packet(st, "modecfg: req", TRUE);
 
     /* RETRANSMIT if Main, SA_REPLACE if Aggressive */
     if(st->st_event->ev_type != EVENT_RETRANSMIT)
@@ -731,7 +734,7 @@ stf_status xauth_send_status(struct state *st, int status)
     init_pbs(&reply, buf, sizeof(buf), "xauth_buf");
 
     /* pick a new message id */
-    st->st_msgid = generate_msgid(st);
+    st->st_msgid_phase15 = generate_msgid(st);
 
     /* HDR out */
     {
@@ -744,7 +747,7 @@ stf_status xauth_send_status(struct state *st, int status)
 	hdr.isa_flags = ISAKMP_FLAG_ENCRYPTION;
 	memcpy(hdr.isa_icookie, st->st_icookie, COOKIE_SIZE);
 	memcpy(hdr.isa_rcookie, st->st_rcookie, COOKIE_SIZE);
-	hdr.isa_msgid = st->st_msgid;
+	hdr.isa_msgid = st->st_msgid_phase15;
 
 	if (!out_struct(&hdr, &isakmp_hdr_desc, &reply, &rbody))
 	{
@@ -785,7 +788,7 @@ stf_status xauth_send_status(struct state *st, int status)
     close_message(&rbody);
     close_output_pbs(&reply);
 
-    init_phase2_iv(st, &st->st_msgid);
+    init_phase2_iv(st, &st->st_msgid_phase15);
     encrypt_message(&rbody, st);
 
     /* free previous transmit packet */
@@ -802,7 +805,7 @@ stf_status xauth_send_status(struct state *st, int status)
 
     /* Transmit */
 
-    send_packet(st, "XAUTH: status");
+    send_packet(st, "XAUTH: status", TRUE);
 
     st->st_state = STATE_XAUTH_R1;
 
@@ -1046,8 +1049,10 @@ static void * do_authentication(void *varg)
         xauth_send_status(st,1);
 
         if(st->quirks.xauth_ack_msgid) {
-	  st->st_msgid = 0;
-	}        
+	  st->st_msgid_phase15 = 0;
+	}
+	pfreeany(st->st_xauth_username);
+	st->st_xauth_username = clone_str(arg->name.ptr,"XAUTH Username");
     } else
     {
 	/** Login attempt failed, display error, send XAUTH status to client
@@ -1263,21 +1268,21 @@ xauth_inR1(struct msg_digest *md)
     if(!st->st_connection->spd.this.modecfg_server) {
 	DBG(DBG_CONTROL
 	    , DBG_log("Not server, starting new exchange"));
-	st->st_msgid = 0;
+	st->st_msgid_phase15 = 0;
     }
 
     if(st->st_connection->spd.this.modecfg_server 
        && st->hidden_variables.st_modecfg_vars_set) {
 	DBG(DBG_CONTROL
 	    , DBG_log("modecfg server, vars are set. Starting new exchange."));
-	st->st_msgid = 0;
+	st->st_msgid_phase15 = 0;
     }
 
     if(st->st_connection->spd.this.modecfg_server 
        && st->st_connection->policy & POLICY_MODECFG_PULL) {
 	DBG(DBG_CONTROL
 	    , DBG_log("modecfg server, pull mode. Starting new exchange."));
-	st->st_msgid = 0;
+	st->st_msgid_phase15 = 0;
     }
     return STF_OK;
 }
@@ -1307,7 +1312,7 @@ modecfg_inR0(struct msg_digest *md)
 
     DBG(DBG_CONTROLMORE, DBG_log("arrived in modecfg_inR0"));
 
-    st->st_msgid = md->hdr.isa_msgid;
+    st->st_msgid_phase15 = md->hdr.isa_msgid;
     CHECK_QUICK_HASH(md
 		     ,xauth_mode_cfg_hash(hash_val
 					  ,hash_pbs->roof
@@ -1407,7 +1412,7 @@ modecfg_inR0(struct msg_digest *md)
 	    }
 
 	    /* they asked us, we reponsed, msgid is done */
-	    st->st_msgid = 0;
+	    st->st_msgid_phase15 = 0;
 	}
     }
 
@@ -1431,11 +1436,11 @@ modecfg_inI2(struct msg_digest *md)
     int resp = LEMPTY;
     stf_status stat;
     struct payload_digest *p;
-    u_int16_t isama_id;
+    u_int16_t isama_id = 0;
 
     DBG(DBG_CONTROL, DBG_log("modecfg_inI2"));
 
-    st->st_msgid = md->hdr.isa_msgid;
+    st->st_msgid_phase15 = md->hdr.isa_msgid;
     CHECK_QUICK_HASH(md
 		     , xauth_mode_cfg_hash(hash_val
 					  ,hash_pbs->roof
@@ -1494,6 +1499,9 @@ modecfg_inI2(struct msg_digest *md)
 			       , sizeof(a.u.v4.sin_addr.s_addr));
 			addrtosubnet(&a, &c->spd.this.client);
 
+			/* make sure that the port info is zeroed */
+			setportof(0, &c->spd.this.client.addr);
+
 			c->spd.this.has_client = TRUE;
 			subnettot(&c->spd.this.client, 0
 				  , caddr, sizeof(caddr));
@@ -1541,7 +1549,7 @@ modecfg_inI2(struct msg_digest *md)
      * we are done with this exchange, clear things so
      * that we can start phase 2 properly
      */
-    st->st_msgid = 0;
+    st->st_msgid_phase15 = 0;
     if(resp) {
 	st->hidden_variables.st_modecfg_vars_set = TRUE;
     }
@@ -1567,7 +1575,7 @@ modecfg_inR1(struct msg_digest *md)
     DBG(DBG_CONTROL, DBG_log("modecfg_inR1"));
     openswan_log("received mode cfg reply");
 
-    st->st_msgid = md->hdr.isa_msgid;
+    st->st_msgid_phase15 = md->hdr.isa_msgid;
     CHECK_QUICK_HASH(md,xauth_mode_cfg_hash(hash_val,hash_pbs->roof, md->message_pbs.roof, st)
 	, "MODECFG-HASH", "MODE R1");
 
@@ -1704,7 +1712,7 @@ modecfg_inR1(struct msg_digest *md)
     }
 
     /* we are done with this exchange, clear things so that we can start phase 2 properly */
-    st->st_msgid = 0;
+    st->st_msgid_phase15 = 0;
     if(resp) {
 	st->hidden_variables.st_modecfg_vars_set = TRUE;
     }
@@ -1806,6 +1814,7 @@ stf_status xauth_client_resp(struct state *st
 		    out_raw(xauth_username, strlen(xauth_username)
 			    ,&attrval, "XAUTH username");
 		    close_output_pbs(&attrval);
+
 		    break;
 		    
 		case XAUTH_USER_PASSWORD:
@@ -1854,9 +1863,10 @@ stf_status xauth_client_resp(struct state *st
 	close_output_pbs(&strattr);
     }
 
-    openswan_log("XAUTH: Answering XAUTH challenge with user='%s'", xauth_username);
+    openswan_log("XAUTH: Answering XAUTH challenge with user='%s'"
+		 , xauth_username);
 
-    xauth_mode_cfg_hash(r_hashval,r_hash_start,rbody->cur,st);
+    xauth_mode_cfg_hash(r_hashval, r_hash_start, rbody->cur, st);
     
     close_message(rbody);
 
@@ -1887,7 +1897,7 @@ xauth_inI0(struct msg_digest *md)
     int len;
     unsigned type;
     char *dat;
-    int status;
+    int status = 0;
     unsigned val;
     stf_status stat;
     bool gotrequest = FALSE;
@@ -1900,7 +1910,7 @@ xauth_inI0(struct msg_digest *md)
 
     DBG(DBG_CONTROLMORE, DBG_log("arrived in xauth_inI0"));
 
-    st->st_msgid = md->hdr.isa_msgid;
+    st->st_msgid_phase15 = md->hdr.isa_msgid;
     CHECK_QUICK_HASH(md, xauth_mode_cfg_hash(hash_val
 					     ,hash_pbs->roof
 					     , md->message_pbs.roof, st)
@@ -1923,7 +1933,8 @@ xauth_inI0(struct msg_digest *md)
 	{
 	default:
 	    openswan_log("Expecting ISAKMP_CFG_REQUEST, got %s instead (ignored)."
-		 , enum_name(&attr_msg_type_names, p->payload.attribute.isama_type));
+			 , enum_name(&attr_msg_type_names
+				     , p->payload.attribute.isama_type));
 	case ISAKMP_CFG_SET:
 	    gotset = TRUE;
 	    break;
@@ -2069,9 +2080,9 @@ xauth_inI0(struct msg_digest *md)
 	}
     }
 
-    /* reset the message ID, tentatively */
-    st->st_msgid2 = st->st_msgid;
-    st->st_msgid = 0;
+    /* reset the message ID */
+    st->st_msgid_phase15b = st->st_msgid_phase15;
+    st->st_msgid_phase15 = 0;
 
     DBG(DBG_CONTROLMORE, DBG_log("xauth_inI0(STF_OK)"));
     return STF_OK;
@@ -2164,7 +2175,7 @@ xauth_inI1(struct msg_digest *md)
 
     DBG(DBG_CONTROLMORE, DBG_log("xauth_inI1"));
 
-    st->st_msgid = md->hdr.isa_msgid;
+    st->st_msgid_phase15 = md->hdr.isa_msgid;
     CHECK_QUICK_HASH(md
 		     , xauth_mode_cfg_hash(hash_val
 					   ,hash_pbs->roof
@@ -2259,6 +2270,40 @@ xauth_inI1(struct msg_digest *md)
 
 
 /*
+ * $Id: xauth.c,v 1.41.4.3 2005/07/26 02:11:23 ken Exp $
+ *
+ * $Log: xauth.c,v $
+ * Revision 1.41.4.3  2005/07/26 02:11:23  ken
+ * Pullin from HEAD:
+ * Split Aggressive mode into ikev1_aggr.c
+ * Fix NAT-T that we broke in dr7
+ * Move dpd/pgp vendor id's to vendor.[ch]
+ *
+ * Revision 1.41.4.2  2005/07/25 19:26:34  ken
+ * Pullin fixes for NAT-T from HEAD
+ * Includes IMPAIR_JACOB_TWO_TWO impairment from HEAD
+ * change from c->interface to st->st_interface for sending packets
+ *
+ * Revision 1.43  2005/07/22 14:05:51  mcr
+ * 	fixes for -Werror warnings.
+ *
+ * Revision 1.42  2005/07/22 14:00:19  mcr
+ * 	fixes for -Werror warnings.
+ *
+ * Revision 1.41  2005/02/16 17:27:41  mcr
+ * 	moved recording of xauth username to after the username
+ * 	has actually been authenticated.
+ * 	Do not record username on client -- I don't think that this
+ * 	makes any sense. If it is important, it should be recorded
+ * 	(and expressed in do_command()) in a different way.
+ *
+ * Revision 1.40  2005/02/14 05:58:46  ken
+ * Add support for saving the XAUTH username, and then passing it to _updown as PLUTO_XAUTH_USERNAME environment variable
+ *
+ * Revision 1.39  2005/01/26 07:01:55  mcr
+ * 	use phase1.5 msgid instead of msgid.
+ *
+ *
  * Local Variables:
  * c-basic-offset:4
  * c-style: pluto
