@@ -1,5 +1,5 @@
 #
-# $Id: net.west.sh,v 1.5 2003/04/10 16:45:15 mcr Exp $
+# $Id: net.west.sh,v 1.6 2004/04/16 19:46:17 mcr Exp $
 #
 
 if [ -n "$UML_west_CTL" ]
@@ -19,9 +19,9 @@ else
     net_eth1="eth1=mcast,10:00:00:64:64:45,239.192.1.2,31200";
 fi
 
-if [ -n "$UML_northpublic_CTL" ]
+if [ -n "$UML_admin_CTL" ]
 then
-    net_eth2="eth2=daemon,10:00:00:32:64:45,unix,$UML_northpublic_CTL,$UML_northpublic_DATA";
+    net_eth2="eth2=daemon,10:00:00:32:64:45,unix,$UML_admin_CTL,$UML_admin_DATA";
 else
     net_eth2="eth2=mcast,10:00:00:32:64:45,239.192.3.2,31210";
 fi
