@@ -7,9 +7,10 @@ TEST_TYPE=klipstest
 TESTNAME=east-ah-icmp-02
 TESTHOST=east
 EXITONEMPTY=--exitonempty
-PRIVINPUT=../inputs/01-sunrise-sunset-ping.pcap
+PRIV_INPUT=../inputs/01-sunrise-sunset-ping.pcap
 THREEEIGHT=true
 REF_PUB_OUTPUT=ah2-output.txt
+REF26_PUB_OUTPUT=ah2-output26.txt
 REF_CONSOLE_OUTPUT=ah2-console.txt
 REF_CONSOLE_FIXUPS="kern-list-fixups.sed nocr.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS klips-spi-sanitize.sed"
