@@ -4,10 +4,11 @@ TEST_TYPE=klipstest
 TESTNAME=east-drop-02
 TESTHOST=east
 EXITONEMPTY=--exitonempty
-PRIVINPUT=../inputs/01-sunrise-sunset-sandwich-nic-ping.pcap
-REFPUBOUTPUT=spi1-output.txt
+PRIV_INPUT=../inputs/01-sunrise-sunset-sandwich-nic-ping.pcap
+REF_PUB_OUTPUT=spi1-output.txt
 THREEEIGHT=true
 REF_CONSOLE_OUTPUT=spi1-console.txt
+REF26_CONSOLE_OUTPUT=spi1-console26.txt
 REF_CONSOLE_FIXUPS="kern-list-fixups.sed nocr.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS klips-spi-sanitize.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS ipsec-look-sanitize.sed"
