@@ -8,8 +8,9 @@ TESTNAME=aggr-unit-01
 TESTHOST=east
 
 REF_CONSOLE_OUTPUT=east-console.txt
+REF26_CONSOLE_OUTPUT=east-console.txt
 
-REF_CONSOLE_FIXUPS="kern-list-fixups.sed nocr.sed"
+REF_CONSOLE_FIXUPS="kern-list-fixups.sed nocr.sed script-only.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS east-prompt-splitline.pl"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS ipsec-setup-sanitize.sed"
 
