@@ -8,7 +8,7 @@ TESTNAME=basic-pluto-01
 EASTHOST=east
 WESTHOST=west
 
-ARPREPLY=--arpreply
+WEST_ARPREPLY=1
 
 EAST_INPUT=../../klips/inputs/01-sunrise-sunset-ping.pcap
 REF_WEST_OUTPUT=../../klips/west-icmp-01/spi1-cleartext.txt
