@@ -3,8 +3,10 @@
 # this script is used by "north" UMLs that want to have per-test
 # configuration files, and will be hitting sunrise-oe to test with.
 
+TESTING=${TESTING-/testing}
+
 mkdir -p /tmp/$TESTNAME
-cp /testing/pluto/$TESTNAME/north.conf /tmp/$TESTNAME/ipsec.conf
+cp ${TESTING}/pluto/$TESTNAME/north.conf /tmp/$TESTNAME/ipsec.conf
 cp /etc/ipsec.secrets                    /tmp/$TESTNAME
 
 mkdir -p /tmp/$TESTNAME/ipsec.d/policies
