@@ -7,6 +7,7 @@ TESTNAME=oe-snat-01
 
 
 REF_CONSOLE_FIXUPS="kern-list-fixups.sed nocr.sed"
+REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS script-only.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS ipsec-look-sanitize.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS east-prompt-splitline.pl"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS klips-debug-sanitize.sed"
@@ -16,10 +17,12 @@ REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS ipsec-setup-sanitize.sed"
 EASTHOST=sunset
 EAST_RUN_SCRIPT=sunsetrun.sh
 REF_EAST_CONSOLE_OUTPUT=sunset-console.txt
+REF26_EAST_CONSOLE_OUTPUT=sunset-console.txt
 
 WESTHOST=west
 WEST_INIT_SCRIPT=pass-init.sh
 REF_WEST_CONSOLE_OUTPUT=west-console.txt
+REF26_WEST_CONSOLE_OUTPUT=west-console.txt
 
 ADDITIONAL_HOSTS="nic"
 
