@@ -1,5 +1,7 @@
 #!/bin/sh
 
+: ==== start ====
+
 PATH=/testing/pluto/bin:$PATH export PATH
 
 export PLUTO="ipsec pluto"
@@ -18,3 +20,4 @@ ln -s /testing/pluto/ipsec.d/east .
 . doauto --diff ipsec-rsa-time-trunc ipsec-rsa-time-neg-dontrekey 
 . doauto --diff ipsec-rsa-delete ipsec-rsa-c ipsec-rsa-co 
 . doauto --diff ipsec-psk-rw ipsec-psk-id-rw ipsec-rsa-rw
+: ==== end ====
