@@ -18,12 +18,14 @@ EASTHOST=east
 EAST_INIT_SCRIPT=eastinit.sh
 EAST_FINAL_SCRIPT=final.sh
 REF_EAST_CONSOLE_OUTPUT=east-console.txt
+REF26_EAST_CONSOLE_OUTPUT=east-console26.txt
 
 ROADHOST=road
 ROAD_INIT_SCRIPT=roadinit.sh
 ROAD_RUN_SCRIPT=roadrun.sh
 ROAD_FINAL_SCRIPT=final.sh
 REF_ROAD_CONSOLE_OUTPUT=road-console.txt
+REF26_ROAD_CONSOLE_OUTPUT=road-console26.txt
 
 ADDITIONAL_HOSTS="nic"
 
