@@ -1,7 +1,7 @@
 #!/usr/bin/expect --
 
 #
-# $Id: Xhost-test.tcl,v 1.17 2004/04/03 19:44:52 ken Exp $
+# $Id: Xhost-test.tcl,v 1.18 2005/02/11 01:31:19 mcr Exp $
 #
 
 if {! [info exists env(OPENSWANSRCDIR)]} {
@@ -269,13 +269,13 @@ foreach host $managed_hosts {
     netjigdebug "Shutting down $host"
     killuml $host
 }
+sleep 5
 
 foreach host $umlid(extra_hosts) {
     netjigdebug "Shutting down extra host: $host"
     shutdown $host
 }
 
-
 log_user 1
 expect -i $netjig1 -gl "*"
 send -i $netjig1 "quit\n"
@@ -288,6 +288,9 @@ expect {
 
 # 
 # $Log: Xhost-test.tcl,v $
+# Revision 1.18  2005/02/11 01:31:19  mcr
+# 	added a sleep to permit UMLs to finish and drain.
+#
 # Revision 1.17  2004/04/03 19:44:52  ken
 # FREESWANSRCDIR -> OPENSWANSRCDIR (patch by folken)
 #
