@@ -1,7 +1,7 @@
 #!/usr/bin/expect --
 
 #
-# $Id: host-test.tcl,v 1.37 2004/04/16 19:55:45 mcr Exp $
+# $Id: host-test.tcl,v 1.38 2004/09/15 21:50:32 mcr Exp $
 #
 
 source $env(OPENSWANSRCDIR)/testing/utils/GetOpts.tcl
@@ -214,8 +214,14 @@ expect {
 	eof
 }
 
+system "sleep 4"
+
 # 
 # $Log: host-test.tcl,v $
+# Revision 1.38  2004/09/15 21:50:32  mcr
+# 	sleep after the test case finishes to give the UML time
+# 	to exit cleanly.
+#
 # Revision 1.37  2004/04/16 19:55:45  mcr
 # 	create "admin" network for "eth2" use.
 #
