@@ -58,7 +58,7 @@ fi
 
 echo "FREESWANDIR=\$BUILDTOP"                                      >>$umlsetup
 echo "REGULARHOSTS='sunrise sunset nic sec beet carrot'"           >>$umlsetup
-echo "FREESWANHOSTS='east west japan road north'"                  >>$umlsetup
+echo "OPENSWANHOSTS='east west japan road north'"                  >>$umlsetup
 
 # setup regression test recording area.
 REGRESSRESULTS=${REGRESSTREE}/${BRANCH}/${YEAR}/${MONTH}/${TODAY} export REGRESSRESULTS
